<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'activer_plugin' => 'Activer le plugin', # NEW
'affichage' => 'Affichage', # NEW
'aide_non_disponible' => 'Pomoc nije dostupna',
'auteur' => 'Auteur&nbsp;:', # NEW
'avis_acces_interdit' => 'Pristup zabranjen.',
'avis_article_modifie' => 'Paznja, @nom_auteur_modif@ je radio na ovom artiklu prije @date_diff@ minuta',
'avis_aucun_resultat' => 'Nije pronadjen nijedan rezultat.',
'avis_chemin_invalide_1' => 'Opcija koju ste izabrali',
'avis_chemin_invalide_2' => 'nije vazeca. Vratite se na  prethodnu stranicu i provjerite unesene podatke.',
'avis_connexion_echec_1' => 'Konekcija na SQL server nije uspijela.', # MODIF
'avis_connexion_echec_2' => 'Vratite se na prethodnu stranicu i provjerite unesene podatke.',
'avis_connexion_echec_3' => '<b>N.B.</b> Na nekim serverima, trebate <b>traziti</b> aktiviranje pristupa SQL bazi prije nego je mozete koristiti. Ako se ne mozete konektovati provjerite da li ste trazili pomenutu aktivaciju.', # MODIF
'avis_connexion_ldap_echec_1' => 'Konekcija na LDAP server nije uspjela.',
'avis_connexion_ldap_echec_2' => 'Vratite se na prethodnu stranicu i provjerite unesene podatke.',
'avis_connexion_ldap_echec_3' => 'Ne koristite podrsku LDAP kao alternativu za importovanje korisnika.',
'avis_conseil_selection_mot_cle' => '<b>Vazna grupa:</b> savjetuje se da izaberete kljucnu rijec za ovu grupu.',
'avis_deplacement_rubrique' => 'Paznja! Ova rubrika sadrzi @contient_breves@ kratke poruke: Ako je zelite premjestiti, oznacite  ovo polje kao potvrdu.',
'avis_destinataire_obligatoire' => 'Trebate naznaciti primaoca prije nego sto posaljete ovu poruku.',
'avis_doublon_mot_cle' => 'Un mot existe deja avec ce titre. &Ecirc;tes vous s&ucirc;r de vouloir cr&eacute;er le m&ecirc;me ?', # NEW
'avis_erreur_connexion_mysql' => 'Greska u SQL konekciji', # MODIF
'avis_erreur_version_archive' => '<b>Paznja! Dokument @archive@  odgovara drugoj verziji SPIP od one koju ste instalirali.</b>  Riskirate velike poteskoce: opasnost od unistenja vase baze podataka, razne disfunkcije stranice, itd. Ne potvrdjujte ovaj zahtjev za importovanje! Za vise informacija pogledajte <a  href="@spipnet@"> SPIP dokumentaciju</a>.', # MODIF
'avis_espace_interdit' => '<b>Zabranjen prostor</b><p>SPIP je  vec instaliran.</p>', # MODIF
'avis_lecture_noms_bases_1' => 'Instalacijski program nije uspio ucitati imena instaliranih baza podataka.',
'avis_lecture_noms_bases_2' => 'Ili nijedna baza nije na  raspolaganju, ili je funkcija, koja dozvoljava izlistavanje  baza, dezaktivirana iz sigurnosnih razloga (sto je slucaj kod  mnogih racunara).',
'avis_lecture_noms_bases_3' => 'Ako je u pitanju druga alternativa, moguce je da se koristi baza koja nosi isto ime kao vas login:',
'avis_non_acces_message' => 'Nemate pristup ovoj poruci.',
'avis_non_acces_page' => 'Nemate pristup ovoj strani.',
'avis_operation_echec' => 'Operacija nije uspijela.',
'avis_operation_impossible' => 'Op&eacute;ration impossible', # NEW
'avis_probleme_archive' => 'Problem kod citanja dokumenta @archive@',
'avis_site_introuvable' => 'Stranica nije pronadjena',
'avis_site_syndique_probleme' => 'Paznja : Problem prilikom sindikacije ove stranice; Doslo je do privremenog prekida sistema. Provjerite adresu dokumenta sindikacije ove stranice \\f1 (<b>@url_syndic@</b>)\\f0  i pokusajte povratiti informacije.', # MODIF
'avis_sites_probleme_syndication' => 'Doslo je do problema  prilikom sindikacije ovih stranica',
'avis_sites_syndiques_probleme' => 'Sindikovane stranice su postavljale problem',
'avis_suppression_base' => 'PAZNJA, brisanje podataka je  nepovratno',
'avis_version_mysql' => 'Vasa SQL verzija (@version_mysql@) ne dozvoljava automatsko popravljanje (ispravljanje) tabela  baze.', # MODIF

// B
'bouton_acces_ldap' => 'Dodaj pristup za LDAP >>', # MODIF
'bouton_ajouter' => 'Dodaj',
'bouton_ajouter_participant' => 'DODAJ UCESNIKA:',
'bouton_annonce' => 'NAJAVA',
'bouton_annuler' => 'Annuler', # NEW
'bouton_checkbox_envoi_message' => 'mogucnost slanja poruke',
'bouton_checkbox_indiquer_site' => 'obavezno naznaciti jednu web stranicu',
'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'administratori stranice',
'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'urendici',
'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'posjetitelji stranice za publiku, ako postavljaju poruku u  forum.',
'bouton_checkbox_signature_unique_email' => 'samo jedan potpis po e-mail adresi',
'bouton_checkbox_signature_unique_site' => 'samo jedan potpis po web stranici',
'bouton_demande_publication' => 'Trazi publikaciju ovog clanka',
'bouton_desactive_tout' => 'Tout d&eacute;sactiver', # NEW
'bouton_desinstaller' => 'D&eacute;sinstaller', # NEW
'bouton_effacer_index' => 'Izbrisi indekse',
'bouton_effacer_statistiques' => 'Effacer les statistiques', # NEW
'bouton_effacer_tout' => 'Izbrisi SVE',
'bouton_envoi_message_02' => 'POSALJI PORUKU',
'bouton_envoyer_message' => 'Definitivna poruka: posalji',
'bouton_forum_petition' => 'PETICIJA & FORUM', # MODIF
'bouton_modifier' => 'Izmijeni',
'bouton_pense_bete' => 'LICNA BILJESKA',
'bouton_radio_activer_messagerie' => 'Aktiviraj interni servis poruka',
'bouton_radio_activer_messagerie_interne' => 'Aktiviraj interni servis poruka',
'bouton_radio_activer_petition' => 'Aktiviraj peticiju',
'bouton_radio_afficher' => 'Prikazi',
'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Prikazi u listi prisutnih urednika',
'bouton_radio_articles_futurs' => 'iskljucivo za sljedece  clanke (bez uticaja na bazupodataka).',
'bouton_radio_articles_tous' => 'bez iznimke za sve clanke.',
'bouton_radio_articles_tous_sauf_forum_desactive' => 'za sve clanke osim onih ciji forum je dezaktiviran.',
'bouton_radio_desactiver_messagerie' => 'Dezaktivirati servis poruka',
'bouton_radio_enregistrement_obligatoire' => 'Obavezno registrovanje (korisnici trebaju upisati svoju e-mail adresu prije mogucnosti postavljanja svojih prijedloga).',
'bouton_radio_envoi_annonces_adresse' => 'Posalji najave na adresu:',
'bouton_radio_envoi_liste_nouveautes' => 'Posalji listu novosti',
'bouton_radio_moderation_priori' => '\\f1 Pre-moderation\\f0  (prijedlozi se ne prikazuju na javnoj stranici prije ovjere od strane administratora).',
'bouton_radio_modere_abonnement' => 'registracija obavezna',
'bouton_radio_modere_posteriori' => '\\f1 post-moderation\\f0 ',
'bouton_radio_modere_priori' => '\\f1 pre-moderation\\f0 ',
'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Ne prikazuj u listi urednika',
'bouton_radio_non_envoi_annonces_editoriales' => 'Ne salji editorijalne najave',
'bouton_radio_non_syndication' => 'Bez sindikacije',
'bouton_radio_pas_petition' => 'Bez peticije',
'bouton_radio_petition_activee' => 'Peticija je aktivirana',
'bouton_radio_publication_immediate' => 'Direktna publikacija poruka (prijedlozi se prikazuju nakon slanja, administratori ih  odmah mogu izbrisati).',
'bouton_radio_sauvegarde_compressee' => 'Snimiti sa kompresijom pod @fichier@', # MODIF
'bouton_radio_sauvegarde_non_compressee' => 'Snimiti bez  kompresije pod @fichier@', # MODIF
'bouton_radio_supprimer_petition' => 'Izbrisi peticiju',
'bouton_radio_syndication' => 'Sindikacija:',
'bouton_redirection' => 'PREUSMJERI',
'bouton_relancer_installation' => 'Ponovo pokreni instalaciju',
'bouton_restaurer_base' => 'Obnovi bazu podataka',
'bouton_suivant' => 'Sljedece',
'bouton_tenter_recuperation' => 'Pokusaj popraviti',
'bouton_test_proxy' => 'Provjeri proxy',
'bouton_vider_cache' => 'Isprazni kes',
'bouton_voir_message' => 'Pregledaj poruku prije ovjere',

// C
'cache_mode_compresse' => 'Dokumenti kesa su snimljeni u kompresovanoj formi;.',
'cache_mode_non_compresse' => 'Dokumenti kesa su pisani u nekompresovanoj formi.',
'cache_modifiable_webmestre' => 'Webmaster stranice moze promijeniti ovaj parametar.',
'calendrier_synchro' => 'Ako koristite neki kompaktibilni kalendarski software <b>iCal</b>, mozete ga uskladiti sa informacijama ove stranice.',
'config_activer_champs' => 'Activer les champs suivants', # NEW
'config_choix_base_sup' => 'indiquer une base sur ce serveur', # NEW
'config_erreur_base_sup' => 'SPIP n\'a pas acc&egrave;s &agrave; la liste des bases accessibles', # NEW
'config_info_base_sup' => 'Si vous avez d\'autres bases de donn&eacute;es &agrave; interroger &agrave; travers SPIP, avec son serveur SQL ou avec un autre, le formulaire ci-dessous, vous permet de les d&eacute;clarer. Si vous laissez certains champs vides, les identifiants de connexion &agrave; la base principale seront utilis&eacute;s.', # NEW
'config_info_base_sup_disponibles' => 'Bases suppl&eacute;mentaires d&eacute;j&agrave; interrogeables:', # NEW
'config_info_enregistree' => 'La nouvelle configuration a &eacute;t&eacute; enregistr&eacute;e', # NEW
'config_info_logos' => 'Chaque &eacute;l&eacute;ment du site peut avoir un logo, ainsi qu\'un &laquo;&nbsp;logo de survol&nbsp;&raquo;', # NEW
'config_info_logos_utiliser' => 'Utiliser les logos', # NEW
'config_info_logos_utiliser_non' => 'Ne pas utiliser les logos', # NEW
'config_info_logos_utiliser_survol' => 'Utiliser les logos de survol', # NEW
'config_info_logos_utiliser_survol_non' => 'Ne pas utiliser les logos de survol', # NEW
'config_info_redirection' => 'En activant cette option, vous pourrez cr&eacute;er des articles virtuels, simples r&eacute;f&eacute;rences d\'articles publi&eacute;s sur d\'autres sites ou hors de SPIP.', # NEW
'config_redirection' => 'Articles virtuels', # NEW
'config_titre_base_sup' => 'D&eacute;claration d\'une base suppl&eacute;mentaire', # NEW
'config_titre_base_sup_choix' => 'Choisissez une base suppl&eacute;mentaire', # NEW
'connexion_ldap' => 'Connexion :', # NEW
'copier_en_local' => 'Copier en local', # NEW

// D
'date_mot_heures' => 'sati',
'diff_para_ajoute' => 'Dodan paragraf',
'diff_para_deplace' => 'Premjesten paragraf',
'diff_para_supprime' => 'Izbrisan paragraf',
'diff_texte_ajoute' => 'Dodan tekst',
'diff_texte_deplace' => 'Premjesten tekst',
'diff_texte_supprime' => 'Izbrisan paragraf',
'double_clic_inserer_doc' => 'Kliknite dva puta ako ovu precicu zelite dodati tekstu',

// E
'email' => 'e-mail',
'email_2' => 'e-mail:',
'en_savoir_plus' => 'En savoir plus', # NEW
'entree_adresse_annuaire' => 'Adresa direktorija',
'entree_adresse_email' => 'Vasa e-mail adresa',
'entree_adresse_fichier_syndication' => 'Adresa dokumenta &laquo;&nbsp;backend&nbsp;&raquo; za sindikaciju:',
'entree_adresse_site' => '<b>Adresa stranice</b> [Obavezno]',
'entree_base_donnee_1' => 'Adresa baze podataka',
'entree_base_donnee_2' => '(Ova adresa cesto odgovara adresi vase stranice, nekada ona odgovara nazivu  &laquo;localhost&raquo;, a nekada je ostavljena prazna.)',
'entree_biographie' => 'Kratka biografija u nekoliko rijeci.',
'entree_breve_publiee' => 'Da li zelite publicirati ovu kratku poruku?',
'entree_chemin_acces' => '<b>Unijeti</b> putanju pristupa:', # MODIF
'entree_cle_pgp' => 'Vas PGP kljuc',
'entree_contenu_rubrique' => '(Sadrzaj ove rubrike, u nekoliko  rijeci.)',
'entree_description_site' => 'O&#1055;&#1048;&#1057; &#1057;&#1058;&#1056;&#1040;&#1053;&#1048;&#1062;&#1045;',
'entree_identifiants_connexion' => 'Identifikatori vase konekcije...',
'entree_informations_connexion_ldap' => 'U ovaj formular unesite informacije o konekciji sa LDAP direktorijem. Administrator mreze ili mreza ce vam pruziti te informacije.',
'entree_infos_perso' => 'Ko ste?',
'entree_interieur_rubrique' => 'U rubrici:',
'entree_liens_sites' => '<b>Hiperlink</b> (Reference, web stranice za posjetiti...)', # MODIF
'entree_login' => 'Vas login',
'entree_login_connexion_1' => 'Login konekcije',
'entree_login_connexion_2' => '(Nekada odgovara vasem loginu za pristup na FTP; nekada je ostavljen prazan)',
'entree_login_ldap' => 'Inicijalni LDAP login',
'entree_mot_passe' => 'Vasa lozinka',
'entree_mot_passe_1' => 'Lozinka konekcije',
'entree_mot_passe_2' => '(Nekada odgovara vasoj lozinki za pristup na FTP, a nekada je ostavljeno prazno)',
'entree_nom_fichier' => 'Unesite ime dokumenta @texte_compresse@:',
'entree_nom_pseudo' => 'Vase ime ili pseudo',
'entree_nom_pseudo_1' => '(Vase ime ili pseudo)',
'entree_nom_site' => 'Ime vase stranice',
'entree_nouveau_passe' => 'Nova lozinka',
'entree_passe_ldap' => 'Lozinka',
'entree_port_annuaire' => 'Broj porta direktorija',
'entree_signature' => 'Potpis',
'entree_texte_breve' => 'Tekst kratke poruke',
'entree_titre_obligatoire' => '<b>Naslov</b> [Obavezno]<br />', # MODIF
'entree_url' => 'URL adresa vase stranice',
'erreur_plugin_desinstalation_echouee' => 'La d&eacute;sinstallation du plugin a echou&eacute;. Vous pouvez n&eacute;anmoins le desactiver.', # NEW
'erreur_plugin_fichier_absent' => 'Fichier absent', # NEW
'erreur_plugin_fichier_def_absent' => 'Fichier de d&eacute;finition absent', # NEW
'erreur_plugin_nom_fonction_interdit' => 'Nom de fonction interdit', # NEW
'erreur_plugin_nom_manquant' => 'Nom du plugin manquant', # NEW
'erreur_plugin_prefix_manquant' => 'Espace de nommage du plugin non d&eacute;fini', # NEW
'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; manquant dans le fichier de d&eacute;finition', # NEW
'erreur_plugin_version_manquant' => 'Version du plugin manquante', # NEW

// F
'forum_info_original' => 'original', # NEW

// H
'htaccess_a_simuler' => 'Avertissement: la configuration de votre serveur HTTP ne tient pas compte des fichiers @htaccess@. Pour pouvoir assurer une bonne s&eacute;curit&eacute;, il faut que vous modifiez cette configuration sur ce point, ou bien que les constantes @constantes@ (d&eacute;finissables dans le fichier mes_options.php) aient comme valeur des r&eacute;pertoires en dehors de @document_root@.', # NEW
'htaccess_inoperant' => 'htaccess inop&eacute;rant', # NEW

// I
'ical_info1' => 'Na ovoj strani je predstavljeno nekoliko metoda kako da ostanete u toku sa aktuelnostima ove web stranice.',
'ical_info2' => 'Za sve informacije o ovim metodama, mozete konsultovati <a href="@spipnet@"> SPIP  dokumentaciju </a>.', # MODIF
'ical_info_calendrier' => 'Na raspolaganju vam stoje dva kalendara. Jedan je plan stranice koji najavljuje sve publicirane artikle. Drugi sadrzi editorijalne najave, kao sto su vase posljednje privatne poruke: On je rezervisan za vas zahvaljujuci licnom kljucu, koji mozete izmijeniti u svakom  momentu, dok mijenjate svoju lozinku.',
'ical_lien_rss_breves' => 'Syndication des br&egrave;ves du site', # NEW
'ical_methode_http' => 'Download',
'ical_methode_webcal' => 'Sinhronizacija (webcal://)',
'ical_texte_js' => 'Jedna linija javascripta vam omogucuje da recentne clanke, objavljene na ovoj web stranici, jako jednostavno objavite na vasoj web stranici.',
'ical_texte_prive' => 'Ovaj kalendar, koji je iskljucivo za licnu upotrebu, obavjestava vas o privatnim editorijalnim  aktivnostima na ovoj stranici (zadaci i licni sastanci, clanci i objavljene kratke poruke).',
'ical_texte_public' => 'Ce calendrier vous permet de suivre l\'activit&eacute; publique de ce site (articles et br&egrave;ves publi&eacute;s).', # NEW
'ical_texte_rss' => 'Novosti sa ove stranice mozete sindikovati u bilo kojem citacu dokumenata XML/RSS (Rich Site Summary). Takodze, to je format koji dozvoljava SPIP-u da cita novosti objavljene na drugim stranicama, koristeci kompatibilan format  za razmjenu (sindikovane stranice).',
'ical_titre_js' => 'Javascript',
'ical_titre_mailing' => 'Mailing-lista',
'ical_titre_rss' => 'Dokumenti &laquo; backend &raquo;',
'icone_activer_cookie' => 'Postavi cookie',
'icone_admin_plugin' => 'Gestion des plugins', # NEW
'icone_afficher_auteurs' => 'Prikazi autore',
'icone_afficher_visiteurs' => 'Prikazi posjetioce',
'icone_arret_discussion' => 'Zavrsi ucesce u ovoj diskusiji',
'icone_calendrier' => 'Kalendar',
'icone_creation_groupe_mots' => 'Kreiraj novu grupu rijeci',
'icone_creation_mots_cles' => 'Kreiraj novu lozinku',
'icone_creer_auteur' => 'Kreiraj novog autora i asociraj ga s ovim clankom',
'icone_creer_mot_cle' => 'Kreiraj novu kljucnu rijec i povezi je sa ovim clankom',
'icone_creer_mot_cle_breve' => 'Cr&eacute;er un nouveau mot-cl&eacute; et le lier &agrave; cette br&egrave;ve', # NEW
'icone_creer_mot_cle_rubrique' => 'Cr&eacute;er un nouveau mot-cl&eacute; et le lier &agrave; cette rubrique', # NEW
'icone_creer_mot_cle_site' => 'Cr&eacute;er un nouveau mot-cl&eacute; et le lier &agrave; ce site', # NEW
'icone_creer_rubrique_2' => 'Kreiraj novu rubriku',
'icone_ecrire_nouvel_article' => 'Kratke poruke sadrzane u ovoj rubrici',
'icone_envoyer_message' => 'Posalji ovu poruku',
'icone_evolution_visites' => 'Nivo posjeta <br />@visites@ posjete', # MODIF
'icone_modif_groupe_mots' => 'Izmijeni ovu grupu rijeci',
'icone_modifier_article' => 'Izmijeni ovaj clanak',
'icone_modifier_breve' => 'Izmijeni ovu kratku poruku',
'icone_modifier_message' => 'Izmijeni ovu poruku',
'icone_modifier_mot' => 'Modifier ce mot-cl&eacute;', # NEW
'icone_modifier_rubrique' => 'Izmijeni ovu rubriku',
'icone_modifier_site' => 'Izmijeni ovu stranicu',
'icone_poster_message' => 'Postavi poruku',
'icone_publier_breve' => 'Objavi ovu kratku poruku',
'icone_referencer_nouveau_site' => 'Preporuciti novu stranicu',
'icone_refuser_breve' => 'Odbij ovu kratku poruku',
'icone_relancer_signataire' => 'Relancer le signataire', # NEW
'icone_retour' => 'Nazad',
'icone_retour_article' => 'Nazad na clanak',
'icone_suivi_forum' => 'Posmatranje javnog foruma: @nb_forums@&nbsp;contribution(s)',
'icone_supprimer_cookie' => 'Izbrisi cookie',
'icone_supprimer_groupe_mots' => 'Izbrisi ovu grupu',
'icone_supprimer_rubrique' => 'Izbrisi ovu rubriku',
'icone_supprimer_signature' => 'Izbrisi ovaj potpis',
'icone_valider_signature' => 'Ovjeri ovaj potpis',
'icone_voir_sites_references' => 'Pogledaj preporucene stranice',
'icone_voir_tous_mots_cles' => 'Pogledaj sve kljucne rijeci',
'image_administrer_rubrique' => 'Mozete biti administrator ove rubrike',
'info_1_article' => '1. clanak',
'info_1_breve' => '1. kratka poruka',
'info_1_site' => '1. stranica',
'info_activer_cookie' => 'Mozete aktivirati jedan <b> cookie za administraciu </b>, koji ce vam dozvoliti lak prelaz iz javnog u privati prostor.',
'info_activer_forum_public' => '<i>Da bi ste aktivirali javne forume, izaberite njihov standardni nacin moderacije</i>', # MODIF
'info_admin_gere_rubriques' => 'Ovaj administrator uredzuje sljedece rubrike:',
'info_admin_gere_toutes_rubriques' => 'Ovaj administrator uredzuje <b>sve rubrike</b>.',
'info_admin_statuer_webmestre' => 'Donner &agrave; cet administrateur les droits de webmestre', # NEW
'info_admin_webmestre' => 'Cet administrateur est <b>webmestre</b>', # NEW
'info_administrateur' => 'Administrator',
'info_administrateur_1' => 'Administrator',
'info_administrateur_2' => 'stranice (<i>pazljiva  upotreba</i>)',
'info_administrateur_site_01' => 'Ako ste administrator stranice',
'info_administrateur_site_02' => 'kliknite ovaj link',
'info_administrateurs' => 'Administratori',
'info_administrer_rubrique' => 'Mozete biti administrator ove rubrike',
'info_adresse' => 'na adresu:',
'info_adresse_email' => 'E-MAIL ADRESA:',
'info_adresse_url' => 'URL adresa stranice za javnost',
'info_afficher_visites' => 'Prikazi posjete za:',
'info_affichier_visites_articles_plus_visites' => 'Prikazi posjete za <b>najposjecenije clanke od pocetka:</b>',
'info_aide_en_ligne' => 'Online pomoc za SPIP',
'info_ajout_image' => 'Ako clanku dodajete fotografije u formi dokumenta, SPIP moze kreirati vinjete (minijature) dodanih  fotografija. To naprimjer dozvoljava automatsko kreiranje  galerije ili portfolija.',
'info_ajout_participant' => 'Dodan je sljedeci ucesnik:',
'info_ajouter_rubrique' => 'Dodaj drugu rubriku za administraciju:',
'info_annonce_nouveautes' => 'Najava novosti',
'info_anterieur' => 'nazad',
'info_appliquer_choix_moderation' => 'Usvoji ovaj izbor moderacije:',
'info_article' => 'clanak',
'info_article_2' => 'clanci',
'info_article_a_paraitre' => 'Prikazi clanke sa kasnijim  datumom',
'info_articles_02' => 'clanci',
'info_articles_2' => 'Clanci',
'info_articles_auteur' => 'Clanci ovog autora',
'info_articles_lies_mot' => 'Clanci vezani za ovu kljucnu rijec',
'info_articles_trouves' => 'Pronadjeni clanci',
'info_articles_trouves_dans_texte' => 'Pronadjeni clanci (u tekstu)',
'info_attente_validation' => 'Vasi clanci koji cekaju ovjeru',
'info_aujourdhui' => 'danas:',
'info_auteur_message' => 'AUTOR PORUKE:',
'info_auteurs' => 'Autori',
'info_auteurs_par_tri' => 'Autori@partri@',
'info_auteurs_trouves' => 'Pronadjeni autori',
'info_authentification_externe' => 'Eksterna autentifikacija',
'info_avertissement' => 'Upozorenje',
'info_barre_outils' => 'avec sa barre d\'outils ?', # NEW
'info_base_installee' => 'Struktura vase baze podatake je instalirana.',
'info_base_restauration' => 'Baza je u toku obnavljanja.',
'info_bloquer' => 'blokirati',
'info_breves' => 'Da li vasa stranica upotrebljava sistem  kratkih poruka?',
'info_breves_03' => 'kratke poruke',
'info_breves_liees_mot' => 'Kratke poruke koje su vezane za ovu kljucnu rijec',
'info_breves_touvees' => 'Pronadjene kratke poruke',
'info_breves_touvees_dans_texte' => 'Pronadjene kratke poruke (u tekstu)',
'info_changer_nom_groupe' => 'Promijeniti ime ove grupe:',
'info_chapeau' => 'Uvod',
'info_chapeau_2' => 'Uvod:',
'info_chemin_acces_1' => 'Opcije: <b>Putanja pristupa u direktorij</b>', # MODIF
'info_chemin_acces_2' => 'Od sada cete morati konfigurisati putanju pristupa informacijama iz direktorija. Ova informacija je neophodna za citanje profila korisnika koji su pohranjeni u direktoriju.',
'info_chemin_acces_annuaire' => 'Opcije : <b>Putanja pristupa u direktorij', # MODIF
'info_choix_base' => 'Treca etapa :',
'info_classement_1' => '<sup>er</sup> iz @liste@',
'info_classement_2' => '<sup>e</sup> iz @liste@',
'info_code_acces' => 'Ne zaboravite vas kod za pristup!',
'info_comment_lire_tableau' => 'Kako citati ovu tabelu',
'info_compresseur_gzip' => '<b>N.&nbsp;B.&nbsp;:</b> Il est recommand&#233; de v&#233;rifier au pr&#233;alable si l\'h&#233;bergeur compresse d&#233;j&#224; syst&#233;matiquement les scripts php&nbsp;; pour cela, vous pouvez par exemple utiliser le service suivant&nbsp;: @testgzip@', # NEW
'info_compresseur_texte' => 'Si votre serveur ne comprime pas automatiquement les pages html pour les envoyer aux internautes, vous pouvez essayer de forcer cette compression pour diminuer le poids des pages t&eacute;l&eacute;charg&eacute;es. <b>Attention</b> : cela peut ralentir considerablement certains serveurs.', # NEW
'info_compresseur_titre' => 'Optimisations et compression', # NEW
'info_config_forums_prive' => 'Dans l&#8217;espace priv&#233; du site, vous pouvez activer plusieurs types de forums&nbsp;:', # NEW
'info_config_forums_prive_admin' => 'Un forum r&#233;serv&#233; aux administrateurs du site&nbsp;:', # NEW
'info_config_forums_prive_global' => 'Un forum global, ouvert &#224; tous les r&#233;dacteurs&nbsp;:', # NEW
'info_config_forums_prive_objets' => 'Un forum sous chaque article, br&#232;ve, site r&#233;f&#233;renc&#233;, etc.&nbsp;:', # NEW
'info_config_suivi' => 'Ako ova adresa odgovara mailing listi, ispod mozete naznaciti adresu na koju se ucesnici mogu registrovati. Ta adresa moze biti URL (npr. strana za  upisivanje na listu putem web-a), ili e-mail adresa opremljena  specificnim subjektom(npr.:  <tt>@adresse_suivi@?subject=prijava</tt>):',
'info_config_suivi_explication' => 'Mozete se prikljuciti mailing-listi ove stranice. Poslije cete u elektronskim putem primiti najave clanaka i kratkih poruka, koje su predlozene za publikaciju',
'info_confirmer_passe' => 'Potvrdi novu lozinku:',
'info_conflit_edition_avis_non_sauvegarde' => 'Attention, les champs suivants ont &#233;t&#233; modifi&#233;s par ailleurs. Vos modifications sur ces champs n\'ont donc pas &#233;t&#233; enregistr&#233;es.', # NEW
'info_conflit_edition_differences' => 'Diff&#233;rences&nbsp;:', # NEW
'info_conflit_edition_version_enregistree' => 'La version enregistr&#233;e&nbsp;:', # NEW
'info_conflit_edition_votre_version' => 'Votre version&nbsp;:', # NEW
'info_connexion_base' => 'Druga etapa: <b>Pokusaj konekcije sa bazom</b>', # MODIF
'info_connexion_base_donnee' => 'Connexion &agrave; votre base de donn&eacute;es', # NEW
'info_connexion_ldap_ok' => 'Uspjesna LDAP konekcija.</b><p>  Mozete pristupiti sljedecoj etapi</p>', # MODIF
'info_connexion_mysql' => 'Prva etapa: <b>Vasa SQL konekcija</b>', # MODIF
'info_connexion_ok' => 'Uspjesna konekcija.',
'info_contact' => 'Kontakt',
'info_contenu_articles' => 'Sadrzaj clanaka',
'info_creation_mots_cles' => 'Ovdje mozete kreirati i konfigurisati kljucne rijeci stranice',
'info_creation_paragraphe' => '(Da biste kreirali odlomke, linije ostavite prazne.)',
'info_creation_rubrique' => 'Prije nego mozete pisati clanke,<br /> morate kreirati najmanje jednu rubriku.<br />', # MODIF
'info_creation_tables' => 'Cetvrta etapa: <b>Kreiranje tabela baze</b>', # MODIF
'info_creer_base' => '<b>Kreirati</b> novu bazu podataka:', # MODIF
'info_dans_groupe' => 'U grupi:',
'info_dans_rubrique' => 'U rubrici:',
'info_date_publication_anterieure' => 'Datum proslog objavljivanja:',
'info_date_referencement' => 'DATUM PREPORUKE OVE STRANICE:',
'info_delet_mots_cles' => 'Zelite izbrisati ovu kljucnu rijec  <b>@titre_mot@</b> (@type_mot@). Ova kljucna rijec je vezana za  <b>@texte_lie@</b> zelite li potvrditi ovu odluku:', # MODIF
'info_derniere_etape' => 'Posljednja etapa: <b>Zavrseno je!', # MODIF
'info_derniere_syndication' => 'Posljednja sindikacija ove stranice je izvrsena',
'info_derniers_articles_publies' => 'Vasi posljednji objavljeni  clanci',
'info_desactiver_forum_public' => 'Dezaktivirati koristenje javnih foruma. Javni forumi mogu dobiti individualnu autorizaciju za clanke; bice zabranjeni za rubrike, kratke  poruke, itd.',
'info_desactiver_messagerie_personnelle' => 'Mozete aktivirati  ili dezaktivirati vas licni servis poruka na ovoj stranici.',
'info_descriptif' => 'Opis:',
'info_desinstaller_plugin' => 'supprime les donn&eacute;es et d&eacute;sactive le plugin', # NEW
'info_discussion_cours' => 'Aktivne diskusije',
'info_ecrire_article' => 'Prije nego mozete pisati clanke, morate kreirati najmanje jednu rubriku.',
'info_email_envoi' => 'E-mail adresa za slanje (fakultativno)',
'info_email_envoi_txt' => 'Ovdje oznacite adresu za slanje e-mailova (po standardu ce adresa primaoca biti koristena kao adresa za slanje):',
'info_email_webmestre' => 'E-mail adresa webmastera (fakultativno)',
'info_entrer_code_alphabet' => 'Unesite kod alfabeta koji ce se koristiti:',
'info_envoi_email_automatique' => 'Automatsko slanje e-mailova',
'info_envoi_forum' => 'Slanje foruma autorima clanaka',
'info_envoyer_maintenant' => 'Posalji sada',
'info_erreur_restauration' => 'Greska u obnavljanju: nepostojeci dokument.',
'info_etape_suivante' => 'Pristupi sljedecoj etapi',
'info_etape_suivante_1' => 'Mozete pristupiti sljedecoj etapi.',
'info_etape_suivante_2' => 'Mozete pristupiti sljedecoj etapi.',
'info_exportation_base' => 'eksportuj baze u @archive@',
'info_facilite_suivi_activite' => 'U svrhu posmatranja  editorijalne aktivnosti stranice, SPIP moze elektronskom postom  (npr. mailing listom urednika) proslijedjivati najave zahtijeva za publikaciju i ovjeru clanaka.',
'info_fichiers_authent' => 'Dokument autentifikacije &laquo;&nbsp;.htpasswd&nbsp;&raquo;',
'info_fonctionnement_forum' => 'Funkcionisanje foruma:',
'info_forum_administrateur' => 'forum administratora',
'info_forum_interne' => 'interni forum',
'info_forum_ouvert' => 'Forum na privatnoj stranici je otvoren svim regristrovanim urednicima. Ispod mozete aktivirati dodatni forum, koji je rezervisan samo za administratore.',
'info_forum_statistiques' => 'Statistike posjeta',
'info_forums_abo_invites' => 'Vasa stranica obudhvata i forume za clanove; posjetioci se pozivaju na registraciju u javnom  prostoru stanice.',
'info_gauche_admin_effacer' => '<b>Ova strana je dostupna samo  osobama odgovornim za web stranicu.</b><p> Ona daje pristup raznim funkcijama tehnickog odrzavanja. Neke od njih pruzaju  mogucnost specificne autentifikacije, koja zahtijeva pristup FTP-u web stranice.</p>', # MODIF
'info_gauche_admin_tech' => '<b>Ova strana je dostupna samo osobama odgovornim za web stranicu.</b><p> Ona daje pristup raznim funkcijama tehnickog odrzavanja. Neke od njih pruzaju  mogucnost specificne autentifikacije, koja zahtijeva pristup FTP-u web stranice.</p>', # MODIF
'info_gauche_admin_vider' => '<b>Ova strana je dostupna samo osobama odgovornim za web stranicu.</b><p> Ona daje pristup raznim funkcijama tehnickog odrzavanja. Neke od njih pruzaju mogucnost specificne autentifikacije, koja zahtijeva pristup FTP-u web stranice.</p>', # MODIF
'info_gauche_auteurs' => 'Ovdje cete pronaci sve autore ove web stranice. Njihov status je naznacen bojom njihove ikone (administrator = zelena; urednik = zuta).',
'info_gauche_auteurs_exterieurs' => 'Vanjski autori bez pristupa stranici su oznaceni plavom ikonom, a izbrisani autori sa ikonicom korpe za smece.',
'info_gauche_messagerie' => 'Servis za slanje poruka vam omogucuje razmjenu poruka medju piscima, cuvanje biljeske (za licnu upotrebu) ili, ako ste administrator, postavljanje najava na pocetnu stranicu u privatnom prostoru.',
'info_gauche_numero_auteur' => 'BROJ AUTORA',
'info_gauche_numero_breve' => 'BROJ KRATKE PORUKE',
'info_gauche_statistiques_referers' => 'Ova strana predstavlja  listu <i>referenci</i>, sto znaci stranice koje sadrze linkove  sa vasom licnom stranicom, ali samo za jucer i danas; ova lista se vraca na nulu svaka 20 sata.',
'info_gauche_suivi_forum' => 'Strana <i>pracenja foruma</i> je alatka za rukovodjene vasom stranicom (ne prostor za diskusiju  i redakciju). Ona izlistava sve doprinose javnog foruma ovog clanka i dozvoljava rukovodjenje tim doprinosima.', # MODIF
'info_gauche_suivi_forum_2' => 'Strana <i>pracenja foruma</i> je alatka za rukovodjene vasom stranicom (ne prostor za  diskusiju i redakciju). Ona izlistava sve doprinose foruma ovog clanka, kako na privatnoj tako i na javnoj stranici, i dozvoljava rukovodjenje tim doprinosima.', # MODIF
'info_gauche_visiteurs_enregistres' => 'Ovdje mozete pronaci posjetioce koji su registrovani na javnoj stranici (forumi za clanove).',
'info_generation_miniatures_images' => 'Obradjivanje minijaturnih slika',
'info_gerer_trad' => 'Zelite li ukljuciti linkove za prevod?',
'info_groupe_important' => 'Vazna grupa',
'info_hebergeur_desactiver_envoi_email' => 'Neki kompjuteri dezaktiviraju automatsko slanje mailova njihovim serverima. U tom slucaju sljedece funkcije SPIP-a nece biti u uptrebi.',
'info_hier' => 'Jucer:',
'info_historique' => 'Revizije:',
'info_historique_activer' => 'Aktivirati pracenje revizija',
'info_historique_affiche' => 'Prikazati reviziju',
'info_historique_comparaison' => 'uporedi',
'info_historique_desactiver' => 'Dezaktivirati pracenje revizija',
'info_historique_lien' => 'Prikazati historiju izmjena',
'info_historique_texte' => 'Pracenje revizija omogucuje ocuvanje historije svih izmjena na sadrzaju clanka i  prikazivanje razlika verzija koje slijede.',
'info_historique_titre' => 'Pracenje revizija',
'info_identification_publique' => 'Vas javni identitet...',
'info_image_process' => 'Izaberite najbolju metodu pravljenja vinjeta tako sto cete kliknuti na odgovarajucu sliku.',
'info_image_process2' => '<b>N.B.</b> <i>Ako se ne pojavljuje nijedna slika, onda vas server nije konfigurisan za koristenje tih funkcija. Ako zelite koristiti te funkcije, kontaktirajte ososbu odgovornu za tehnicko odrzavanje i pitajte za extenzije &laquo;GD&raquo; ili  &laquo;Imagick&raquo;.</i>',
'info_images_auto' => 'Automatski izracunate slike',
'info_informations_personnelles' => 'Peta etapa: <b>Licne informacije</b>', # MODIF
'info_inscription_automatique' => 'Automatsko upisivanje novih urednika',
'info_jeu_caractere' => 'Set karaktera stranice',
'info_jours' => 'dani',
'info_laisser_champs_vides' => 'ostavi ova polja prazna)',
'info_langues' => 'Jezici stranice',
'info_ldap_ok' => 'LDAP autentifikacija je instalirana.',
'info_lien_hypertexte' => 'Hiperlink:',
'info_liens_syndiques_1' => 'sindikovani linkovi',
'info_liens_syndiques_2' => 'na cekanju za ovjeru.',
'info_liens_syndiques_3' => 'forumi',
'info_liens_syndiques_4' => 'su',
'info_liens_syndiques_5' => 'forum',
'info_liens_syndiques_6' => 'je',
'info_liens_syndiques_7' => 'na cekanju za ovjeru',
'info_liste_redacteurs_connectes' => 'Lista konektovanih urednika',
'info_login_existant' => 'Ovaj login vec postoji.',
'info_login_trop_court' => 'Ovaj login je prekratak.',
'info_logos' => 'Les logos', # NEW
'info_maximum' => 'maksimalno:',
'info_meme_rubrique' => 'U istoj rubrici',
'info_message' => 'Poruka od',
'info_message_efface' => 'PORUKA IZBRISANA',
'info_message_en_redaction' => 'Vase poruke u toku uredjivanja',
'info_message_technique' => 'Tehnicka poruka:',
'info_messagerie_interne' => 'Interni servis za poruke',
'info_mise_a_niveau_base' => 'nadogradnja vase SQL baze', # MODIF
'info_mise_a_niveau_base_2' => '\\{\\{Paznja!\\}\\} Instalirali ste verziju SPIP dokumenata, koji su stariji od one koja je vec postojala na stranici: vasa baza podataka je vjerovatno izgubljena i vasa stranica vise nece funkcionisati.  <br />\\{\\{Ponovo instalirajte SPIP dokumente\\}\\}', # MODIF
'info_mode_fonctionnement_defaut_forum_public' => 'Standardni nacin funkcionisanja javnih foruma',
'info_modifier_auteur' => 'Modifier l\'auteur :', # NEW
'info_modifier_breve' => 'Izmijeni kratku poruku:',
'info_modifier_mot' => 'Modifier le mot-cl&eacute; :', # NEW
'info_modifier_rubrique' => 'Izmijeni rubriku:',
'info_modifier_titre' => 'Izmijeni: @titre@',
'info_mon_site_spip' => 'Moja SPIP stranica',
'info_mot_sans_groupe' => '(Kljucne rijeci bez grupe...)',
'info_moteur_recherche' => 'integrisani motor za pretragu',
'info_mots_cles' => 'Kljucne rijeci',
'info_mots_cles_association' => 'Kljucne rijeci ove grupe mogu  biti asocirane sa:',
'info_moyenne' => 'prosjek:',
'info_multi_articles' => 'Aktivirati jezicki meni za clanke?',
'info_multi_cet_article' => 'Jezik ovog clanka:',
'info_multi_langues_choisies' => 'Izaberite jezike koji ce biti na raspolaganju urednicima vase stranice. Jezici koji se vec koriste na vasoj stranici, ne mogu se iskluciti.',
'info_multi_rubriques' => 'Aktivirati jezicki meni za rubrike?',
'info_multi_secteurs' => '... samo za rubrike koje se nalaze na root-u?',
'info_nom' => 'Ime',
'info_nom_destinataire' => 'Ime primaoca',
'info_nom_site' => 'Ime vase stranice',
'info_nom_site_2' => '<b>Ime stranice</b> [Obavezno]',
'info_nombre_articles' => '@nb_articles@ clanci,',
'info_nombre_breves' => '@nb_breves@ kratke poruke,',
'info_nombre_partcipants' => 'UCESNICI DISKUSIJE:',
'info_nombre_rubriques' => '@nb_rubriques@ rubrike,',
'info_nombre_sites' => '@nb_sites@ stranice,',
'info_non_deplacer' => 'Ne premijestati...',
'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP moze regularno poslati najavu posljednjih novosti stranice (recentno objavljeni clanci i kratke poruke).',
'info_non_envoi_liste_nouveautes' => 'Ne slati listu novosti',
'info_non_modifiable' => 'Ne moze se modifikovati',
'info_non_suppression_mot_cle' => 'Ne zelim izbrisati ovu kljucnu rijec.',
'info_notes' => 'Biljeske',
'info_nouveaux_message' => 'Nove poruke',
'info_nouvel_article' => 'Novi clanak',
'info_nouvelle_traduction' => 'Novi prevod:',
'info_numero_article' => 'CLANAK BROJ:',
'info_obligatoire_02' => '[Obavezno]',
'info_option_accepter_visiteurs' => 'Prihvati upisivanje posjetioca na javnoj stranici',
'info_option_email' => 'Kada posjetioc sranice postavi novu poruku u forum vezan za neki clanak, autori clanka mogu biti o tome upozoreni putem e-maila. Zelite li koristiti ovu opciju?', # MODIF
'info_option_faire_suivre' => 'Omoguci autorima clanaka pracenje poruka na forumima',
'info_option_ne_pas_accepter_visiteurs' => 'Odbij upisivanje posjetioca',
'info_option_ne_pas_faire_suivre' => 'Onemoguci prosljedjivanje poruka na forumima',
'info_options_avancees' => 'NAPREDNE OPCIJE',
'info_ortho_activer' => 'Aktiviraj ortografsku provjeru',
'info_ortho_desactiver' => 'Dezaktiviraj ortografsku provjeru',
'info_ou' => 'ili...',
'info_oui_suppression_mot_cle' => 'definitivno izbrisati ovu kljucnu rijec.',
'info_page_interdite' => 'Ova strana je zabranjena',
'info_par_nom' => 'par nom', # NEW
'info_par_nombre_article' => '(po broju clanaka)', # MODIF
'info_par_statut' => 'par statut', # NEW
'info_par_tri' => '\'(par @tri@)\'', # NEW
'info_pas_de_forum' => 'nema foruma',
'info_passe_trop_court' => 'Prekratka lozinka.',
'info_passes_identiques' => 'Lozinke nisu identicne.',
'info_pense_bete_ancien' => 'Vase stare biljeske', # MODIF
'info_plus_cinq_car' => 'vise od pet karaktera',
'info_plus_cinq_car_2' => '(Vise od pet karaktera)',
'info_plus_trois_car' => '(Vise od tri karaktera)',
'info_popularite' => 'popularnosti:&nbsp;@popularite@&nbsp;;  posjete:&nbsp;@visites@',
'info_popularite_2' => 'popularnosti stranice;:',
'info_popularite_3' => 'popularnosti:&nbsp;@popularite@&nbsp;;  posjete:&nbsp;@visites@',
'info_popularite_4' => 'popularnost:&nbsp;@popularite@&nbsp;;  posjete:&nbsp;@visites@',
'info_post_scriptum' => 'Post-Scriptum',
'info_post_scriptum_2' => 'Post-scriptum :',
'info_pour' => 'za',
'info_preview_admin' => 'Samo administratori mogu stranicu pogledati online',
'info_preview_comite' => 'Svi urednici mogu stranicu pogledati online',
'info_preview_desactive' => 'Nije moguce pogledati stranicu online. Ova opcija je dezaktivirana.',
'info_preview_texte' => 'Moguce je stranicu pogledati online, kao da su svi clanci i kratke poruke objavljene, ukoliko iste imaju &laquo;&nbsp;predlozen&nbsp;&raquo; status. Da li ova opcija treba biti otvorena samo administratorima, svim urednicima ili nikome?',
'info_principaux_correspondants' => 'Vasi glavni korespodenti',
'info_procedez_par_etape' => 'Slijedite etape',
'info_procedure_maj_version' => 'Potrebno je pokrenuti update, da bi se baza podataka prikljucila novoj verziji SPIP-a.',
'info_proxy_ok' => 'Test du proxy r&eacute;ussi.', # NEW
'info_ps' => 'P.S.:', # MODIF
'info_publier' => 'objavi moje clanke',
'info_publies' => 'Vos articles publi&eacute;s en ligne', # NEW
'info_question_accepter_visiteurs' => 'Ako obrasci vase stranice ukljucuju upisivanje posjetioca bez pristupa u  privatnu stranicu, aktivirajte sljedecu opciju:',
'info_question_activer_compactage_css' => 'Souhaitez-vous activer le compactage des feuilles de style (CSS) ?', # NEW
'info_question_activer_compactage_js' => 'Souhaitez-vous activer le compactage des scripts (javascript) ?', # NEW
'info_question_activer_compresseur' => 'Voulez-vous activer la compression du flux HTTP ?', # NEW
'info_question_gerer_statistiques' => 'Treba li vasa stranica uredjivati statistike posjeta?',
'info_question_inscription_nouveaux_redacteurs' => 'Da li prihvatate upisivanje novih urednika u javnom prostoru  stranice? Ako prihvatate, posjetioci ce se moci registrovati putem automatskog formulara, a zatim ce moci pristupiti privatnom prostoru i predlagati svoje clanke. <blockquote><i>Tokom faze upisivanja, korisnici ce primiti  automatski e-mail sa kodom za pristup u privatnu stranicu. Neki kompjuteri sprecavaju slanje mailova putem njihovih servera: u tom slucaju ce automatsko upisivanje biti nemoguce.', # MODIF
'info_question_mots_cles' => 'Zelite li koristiti kljucne rijeci na vasoj stranici?',
'info_question_proposer_site' => 'Ko moze predloziti preporucene stranice?',
'info_question_utilisation_moteur_recherche' => 'Zelite li koristiti motor pretrage koji je integrisan u SPIP? (dezaktiviranje ove opcije ubrzava funkcionisanje sistema.)',
'info_question_vignettes_referer' => 'Lorsque vous consultez les statistiques, vous pouvez visualiser des aper&ccedil;us des sites d\'origine des visites', # NEW
'info_question_vignettes_referer_non' => 'Ne pas afficher les captures des sites d\'origine des visites', # NEW
'info_question_vignettes_referer_oui' => 'Afficher les captures des sites d\'origine des visites', # NEW
'info_question_visiteur_ajout_document_forum' => 'Si vous souhaitez autoriser les visiteurs &#224; joindre des documents (images, sons...) &#224; leurs messages de forum, indiquer ci-dessous la liste des extensions de documents autoris&#233;s pour les forums (ex: gif, jpg, png, mp3).', # NEW
'info_question_visiteur_ajout_document_forum_format' => 'Si vous souhaitez autoriser tous les types de documents consid&eacute;r&eacute;s comme fiables par SPIP, mettre une &eacute;toile. Pour ne rien autoriser, ne rien indiquer.', # NEW
'info_qui_attribue_mot_cle' => 'Rijeci ove grupe mogu biti dodane od strane:',
'info_racine_site' => 'Korjen stranice',
'info_recharger_page' => 'Restartujte ovu stranicu za nekoliko momenata.',
'info_recherche_auteur_a_affiner' => 'Previse rezultata za "@cherche_auteur@"; redefinisite opcije pretrage.',
'info_recherche_auteur_ok' => 'Pronadjeno je vise urednika za  "@cherche_auteur@":',
'info_recherche_auteur_zero' => 'Nema rezultata za &laquo;&nbsp;@cherche_auteur@&nbsp;&raquo;.',
'info_recommencer' => 'Pocnite ponovo.',
'info_redacteur_1' => 'Urednik',
'info_redacteur_2' => 'koji ima/ju pristup privatnoj stranici (<i>recommand&eacute;</i>)',
'info_redacteurs' => 'Urednici',
'info_redaction_en_cours' => 'U TOKU UREDJIVANJA',
'info_redirection' => 'Preusmjerenje',
'info_referencer_doc_distant' => 'Preporuciti dokument na internetu:',
'info_refuses' => 'Vasi odbijeni clanci',
'info_reglage_ldap' => 'Opcije: namijestanje LDAP importa</b>', # MODIF
'info_renvoi_article' => '<b>Preusmjerenje.</b> Ovaj clanak se preusmjerava na stranicu:', # MODIF
'info_reserve_admin' => 'Samo administratori mogu izmijeniti ovu adresu.',
'info_restauration_sauvegarde' => 'obnavljanje backup arhiva @archive@', # MODIF
'info_restauration_sauvegarde_insert' => 'Insertion de @archive@ dans la base', # NEW
'info_restreindre_rubrique' => 'Ograniciti uredjivanje rubrike:',
'info_resultat_recherche' => 'Rezultati pretrage:',
'info_rubriques' => 'Rubrike',
'info_rubriques_02' => 'rubrike',
'info_rubriques_liees_mot' => 'Rubrike vezane za ovu kljucnu rijec',
'info_rubriques_trouvees' => 'Pronadjene rubrike',
'info_rubriques_trouvees_dans_texte' => 'Pronadjene rubrike (u ovom tekstu)',
'info_sans_titre' => 'Bez naslova',
'info_sauvegarde' => 'Arhiva',
'info_sauvegarde_articles' => 'Backup clanaka',
'info_sauvegarde_articles_sites_ref' => 'Backup clanaka preporucenih stranica',
'info_sauvegarde_auteurs' => 'Backup autora',
'info_sauvegarde_breves' => 'Backup kratkih poruka',
'info_sauvegarde_documents' => 'Backup dokumenata',
'info_sauvegarde_echouee' => 'Ako backup nije uspjeo(&laquo;Dostignuto je maksimalno vrijeme izvrsavanja&raquo;),',
'info_sauvegarde_forums' => 'Backup forum\\tab ',
'info_sauvegarde_groupe_mots' => 'Backup grupa rijeci',
'info_sauvegarde_messages' => 'Backup poruka',
'info_sauvegarde_mots_cles' => 'Backup kljucnih rijeci',
'info_sauvegarde_petitions' => 'Backup peticija',
'info_sauvegarde_refers' => 'Backup refera',
'info_sauvegarde_reussi_01' => 'Backup uspijeo.',
'info_sauvegarde_reussi_02' => 'Baza je pohranjena u @archive@. Mozete se', # MODIF
'info_sauvegarde_reussi_03' => 'vratiti uredjivanju',
'info_sauvegarde_reussi_04' => 'vase stranice.',
'info_sauvegarde_rubrique_reussi' => 'Les tables de la rubrique @titre@ ont &eacute;t&eacute; sauvegard&eacute;e dans @archive@. Vous pouvez', # NEW
'info_sauvegarde_rubriques' => 'Backup rubrika',
'info_sauvegarde_signatures' => 'Backup potpisa peticija',
'info_sauvegarde_sites_references' => 'Backup preporucenih stranica',
'info_sauvegarde_type_documents' => 'Backup tipova dokumenata',
'info_sauvegarde_visites' => 'Backup posjeta',
'info_selection_chemin_acces' => '<b>Izaberite</b> putanju pristupa direktoriju:',
'info_selection_un_seul_mot_cle' => 'Moguce je izabrati <b>samo po jednu kljucnu rijec</b> u ovoj grupi.',
'info_signatures' => 'potpisi',
'info_site' => 'Stranica',
'info_site_2' => 'stranica:',
'info_site_min' => 'stranica',
'info_site_propose' => 'Stranica preporucena:',
'info_site_reference_2' => 'Preporucena stranica',
'info_site_syndique' => 'Ova stranica je sindikovana...',
'info_site_valider' => 'Stranice za ovjeriti',
'info_site_web' => 'WEB STRANICA :',
'info_sites' => 'stranice',
'info_sites_lies_mot' => 'Preporucene stranice koje su vezane za ovu kljucnu rijec',
'info_sites_proxy' => 'Koristi proxy',
'info_sites_refuses' => 'Odbijene stranice',
'info_sites_trouves' => 'Pronadjene stranice',
'info_sites_trouves_dans_texte' => 'Pronadjene stranice (u tekstu)',
'info_sous_titre' => 'Podnaslov:',
'info_statut_administrateur' => 'Administrator',
'info_statut_auteur' => 'Status ovog autora:', # MODIF
'info_statut_auteur_a_confirmer' => 'Inscription &agrave; confirmer', # NEW
'info_statut_auteur_autre' => 'Autre statut&nbsp;:', # NEW
'info_statut_efface' => 'Izbrisano',
'info_statut_redacteur' => 'Urednik',
'info_statut_site_1' => 'Ova stranica je:',
'info_statut_site_2' => 'Objavljena',
'info_statut_site_3' => 'Predlozena',
'info_statut_site_4' => 'U korpi za smece',
'info_statut_utilisateurs_1' => 'Standardni status importovanih korisnika',
'info_statut_utilisateurs_2' => 'Izaberita koji status ce imati osobe koje su prisutne u LDAP direktoriju, kada se konektuju  prvi put. Kasnije ce te biti u mogucnosti da status svakog autora individualno izmijenite.',
'info_suivi_activite' => 'Pracenje urednicke aktivnosti',
'info_supprimer_mot' => 'Izbrisati ovu rijec',
'info_surtitre' => 'Nadnaslov:',
'info_syndication_integrale_1' => 'Votre site propose des fichiers de syndication (voir &laquo;&nbsp;<a href="@url@">@titre@</a>&nbsp;&raquo;).', # NEW
'info_syndication_integrale_2' => 'Souhaitez-vous transmettre les articles dans leur int&eacute;gralit&eacute;, ou ne diffuser qu\'un r&eacute;sum&eacute; de quelques centaines de caract&egrave;res&nbsp;?', # NEW
'info_table_prefix' => 'Vous pouvez modifier le pr&eacute;fixe du nom des tables de donn&eacute;es (ceci est indispensable lorsque l\'on souhaite installer plusieurs sites dans la m&ecirc;me base de donn&eacute;es). Ce pr&eacute;fixe s\'&eacute;crit en lettres minuscules, non accentu&eacute;es, et sans espace.', # NEW
'info_taille_maximale_images' => 'SPIP va tester la taille maximale des images qu\'il peut traiter (en millions de pixels).<br /> Les images plus grandes ne seront pas r&eacute;duites.', # NEW
'info_taille_maximale_vignette' => 'Maksimalna velicina vinjeta  koje uredjuje sistem:',
'info_terminer_installation' => 'Sada mozete zavrsiti standardnu proceduru instalacije.',
'info_texte' => 'Tekst',
'info_texte_explicatif' => 'Eksplikacioni tekst',
'info_texte_long' => '(Ovaj tekst je dug, a zato je prikazan u vise dijelova, koji ce biti sastavljeni poslije ovjere.)',
'info_texte_message' => 'Tekst vase poruke:',
'info_texte_message_02' => 'Tekst poruke',
'info_titre' => 'Naslov:',
'info_titre_mot_cle' => 'Ime ili naslov kljucne rijeci',
'info_total' => 'total:',
'info_tous_articles_en_redaction' => 'Svi clanci koji su fazi obradjivanja',
'info_tous_articles_presents' => 'Svi objavljeni clanci u ovoj rubrici',
'info_tous_articles_refuses' => 'Tous les articles refus&eacute;s', # NEW
'info_tous_les' => 'svi:',
'info_tous_redacteurs' => 'Najava svim urednicima',
'info_tout_site' => 'Citava web stranica',
'info_tout_site2' => 'Clanak nije preveden na ovaj jezik.',
'info_tout_site3' => 'Clanak je preveden na ovaj jezik, ali su usvojene izmjene preporucenog clanka. Potrebno je obnoviti  prevod.',
'info_tout_site4' => 'Clanak je preveden na ovaj jezik i prevod je obnovljen.',
'info_tout_site5' => 'Originalni clanak.',
'info_tout_site6' => '<b>Paznja:</b> prikazani su samo originalni clanci.
Prevodi su (sa bojom koja ukazuje na njihovo stanje) povezani sa originalnim clankom:',
'info_travail_colaboratif' => 'Saradnicki rad na clancima',
'info_un_article' => 'clanak,',
'info_un_mot' => 'Samo po jedna rijec',
'info_un_site' => 'jedna stranica,',
'info_une_breve' => 'jedna kratka poruka,',
'info_une_rubrique' => 'jedna rubrika,',
'info_une_rubrique_02' => '1 rubrika',
'info_url' => 'URL:',
'info_url_site' => 'URL WEB STRANICE:',
'info_urlref' => 'Hiperlink:',
'info_utilisation_spip' => 'Mozete poceti sa koristenjem sistema za asistirano objavljivanje...',
'info_visites_par_mois' => 'Prikazi po mjesecu:',
'info_visites_plus_populaires' => 'Prikazi posjete <b>najpopularnijih clanaka</b> i <b>posljednjih objavljenih clanaka:</b>',
'info_visiteur_1' => 'posjetioc',
'info_visiteur_2' => 'javne stranice',
'info_visiteurs' => 'posjetioci',
'info_visiteurs_02' => 'Posjetioci javne stranice',
'install_adresse_base_hebergeur' => 'Adresse de la base de donn&eacute;es attribu&eacute;e par l\'h&eacute;bergeur', # NEW
'install_base_ok' => 'La base @base@ a &eacute;t&eacute; reconnue', # NEW
'install_echec_annonce' => 'Instalacija vjerovatno nece uspjeti, ili ce rezultirati nefunkcionirajucom stranicom...',
'install_extension_mbstring' => 'SPIP ne funkcionise sa:',
'install_extension_php_obligatoire' => 'SPIP-u je potrebna php ekstenzija:',
'install_login_base_hebergeur' => 'Login de connexion attribu&eacute; par l\'h&eacute;bergeur', # NEW
'install_nom_base_hebergeur' => 'Nom de la base attribu&eacute; par l\'h&eacute;bergeur&nbsp;:', # NEW
'install_pas_table' => 'Base actuellement sans tables', # NEW
'install_pass_base_hebergeur' => 'Mot de passe de connexion attribu&eacute; par l\'h&eacute;bergeur', # NEW
'install_php_version' => 'PHP version @version@ insuffisant (minimum = @minimum@)', # NEW
'install_select_langue' => 'Izaberite jezik, a zatim kliknite na dugme &laquo;&nbsp;sljedece&nbsp;&raquo; da bi pokrenuli proces instalacije.',
'install_select_type_db' => 'Indiquer le type de base de donn&eacute;es&nbsp;:', # NEW
'install_select_type_mysql' => 'MySQL', # NEW
'install_select_type_pg' => 'PostgreSQL', # NEW
'install_select_type_sqlite2' => 'SQLite 2', # NEW
'install_select_type_sqlite3' => 'SQLite 3', # NEW
'install_serveur_hebergeur' => 'Serveur de base de donn&eacute;es attribu&eacute; par l\'h&eacute;bergeur', # NEW
'install_table_prefix_hebergeur' => 'Pr&eacute;fixe de table attribu&eacute; par l\'h&eacute;bergeur&nbsp;:', # NEW
'install_tables_base' => 'Tables de la base', # NEW
'install_types_db_connus' => 'SPIP sait utiliser <b>MySQL</b> (le plus r&eacute;pandu), <b>PostgreSQL</b> et <b>SQLite</b>.', # NEW
'install_types_db_connus_avertissement' => 'Attention&nbsp;: plusieurs plugins ne fonctionnent qu\'avec MySQL', # NEW
'intem_redacteur' => 'urednik',
'intitule_licence' => 'Licence', # NEW
'item_accepter_inscriptions' => 'Prihvati upise',
'item_activer_forum_administrateur' => 'Aktiviraj forum administratora',
'item_activer_messages_avertissement' => 'Aktiviraj poruke upozorenja',
'item_administrateur_2' => 'administrator',
'item_afficher_calendrier' => 'Prikazati u kalendaru',
'item_ajout_mots_cles' => 'Odobri dodavanje kljucnih rijeci u forum',
'item_autoriser_documents_joints' => 'Ododbri dokumente pridruzene clancima',
'item_autoriser_documents_joints_rubriques' => 'Odobri dokumente u rubrikama',
'item_autoriser_selectionner_date_en_ligne' => 'Permettre de modifier la date de chaque document', # NEW
'item_autoriser_syndication_integrale' => 'Diffuser l\'int&eacute;gralit&eacute; des articles dans les fichiers de syndication', # NEW
'item_bloquer_liens_syndiques' => 'Blokiraj sindikovane linkove za validaciju',
'item_breve_refusee' => 'NE - Kratka poruka odbijena',
'item_breve_validee' => 'DA - Kratka poruka ovjerena',
'item_choix_administrateurs' => 'administratori',
'item_choix_generation_miniature' => 'Automatski uredi minijature slika.',
'item_choix_non_generation_miniature' => 'Ne uredjuj minijature slika.',
'item_choix_redacteurs' => 'urednici',
'item_choix_visiteurs' => 'posjetioci javne stranice',
'item_compresseur' => 'Activer la compression', # NEW
'item_config_forums_prive_global' => 'Activer le forum des r&#233;dacteurs', # NEW
'item_config_forums_prive_objets' => 'Activer ces forums', # NEW
'item_creer_fichiers_authent' => 'kreiraj dokumente .htpasswd',
'item_desactiver_forum_administrateur' => 'Dezaktiviraj forum za administratore',
'item_gerer_annuaire_site_web' => 'Uredi direktorij za web stranice',
'item_gerer_statistiques' => 'Uredi statistike',
'item_limiter_recherche' => 'Pretragu ograniciti na informacije sa vase stranice',
'item_login' => 'Login',
'item_messagerie_agenda' => 'Activer la messagerie et l&#8217;agenda', # NEW
'item_mots_cles_association_articles' => 'za clanke',
'item_mots_cles_association_breves' => 'za kratke poruke',
'item_mots_cles_association_rubriques' => 'za rubrike',
'item_mots_cles_association_sites' => 'Za preporucene ili sindikovane stranice.',
'item_non' => 'Ne',
'item_non_accepter_inscriptions' => 'Ne dozvoljavaj upise',
'item_non_activer_messages_avertissement' => 'Bez poruka upozorenja',
'item_non_afficher_calendrier' => 'Ne prikazuj u kalendaru',
'item_non_ajout_mots_cles' => 'Zabrani upotrebu kljucnih rijeci u forumu',
'item_non_autoriser_documents_joints' => 'Ne odobravaj dokumente bez clanaka',
'item_non_autoriser_documents_joints_rubriques' => 'Ne odobravaj dokumente u rubrikama',
'item_non_autoriser_selectionner_date_en_ligne' => 'La date des documents est celle de leur ajout sur le site', # NEW
'item_non_autoriser_syndication_integrale' => 'Ne diffuser qu\'un r&eacute;sum&eacute;', # NEW
'item_non_bloquer_liens_syndiques' => 'Ne blokiraj linkove koji su rezultat sindikacije',
'item_non_compresseur' => 'D&#233;sactiver la compression', # NEW
'item_non_config_forums_prive_global' => 'D&#233;sactiver le forum des r&#233;dacteurs', # NEW
'item_non_config_forums_prive_objets' => 'D&#233;sactiver ces forums', # NEW
'item_non_creer_fichiers_authent' => 'Ne kreiraj ove dokumente',
'item_non_gerer_annuaire_site_web' => 'Dezaktiviraj direktorij web stranica',
'item_non_gerer_statistiques' => 'Ne uredjuj statistike',
'item_non_limiter_recherche' => 'Pretragu prosiriti na sadrzaj preporuka',
'item_non_messagerie_agenda' => 'D&#233;sactiver la messagerie et l&#8217;agenda', # NEW
'item_non_publier_articles' => 'Ne objavljuj clanke poslije datuma odredjenog za publikaciju.',
'item_non_utiliser_breves' => 'Ne koristiti kratke poruke',
'item_non_utiliser_config_groupe_mots_cles' => 'Ne koristi naprednu konfiguraciju grupa kljucnih rijeci',
'item_non_utiliser_moteur_recherche' => 'Ne koristi motor',
'item_non_utiliser_mots_cles' => 'Ne koristi kljucne rijeci',
'item_non_utiliser_syndication' => 'Ne koristi automatsku sindikaciju',
'item_nouvel_auteur' => 'Novi autor',
'item_nouvelle_breve' => 'Nova kratka poruka',
'item_nouvelle_rubrique' => 'Nova rubrika',
'item_oui' => 'Da',
'item_publier_articles' => 'Objavi clanke bez obzira na datum odredjen za njihovu publikaciju.',
'item_reponse_article' => 'Odgovor na clanak',
'item_utiliser_breves' => 'Koristi kratke poruke',
'item_utiliser_config_groupe_mots_cles' => 'Koristi naprednu konfiguraciju grupa kljucnih rijeci',
'item_utiliser_moteur_recherche' => 'Koristi motor za pretragu',
'item_utiliser_mots_cles' => 'Koristi kljucne rijeci',
'item_utiliser_syndication' => 'Koristi automatsku sindikaciju',
'item_visiteur' => 'posjetioc',

// J
'jour_non_connu_nc' => 'nepoznato',

// L
'lien_ajout_destinataire' => 'Dodaj ovog primaoca',
'lien_ajouter_auteur' => 'Dodaj ovog autora',
'lien_ajouter_participant' => 'Dodaj ucesnika',
'lien_email' => 'e-mail',
'lien_forum_public' => 'Uredi javni forum ovog clanka',
'lien_mise_a_jour_syndication' => 'Osvjezi sada',
'lien_nom_site' => 'IME STRANICE:',
'lien_nouvelle_recuperation' => 'Pokusaj ponovno dobavljanje podataka',
'lien_reponse_article' => 'Odgovori na clanak',
'lien_reponse_breve' => 'Odgovori na kratku poruku',
'lien_reponse_breve_2' => 'Odgovori na kratku poruku',
'lien_reponse_rubrique' => 'Odgovori na rubriku',
'lien_reponse_site_reference' => 'Odgovori na referenciranu stranicu:',
'lien_retirer_auteur' => 'Odstrani autora',
'lien_retrait_particpant' => 'Odstrani ovog ucesnika',
'lien_site' => 'stranica',
'lien_supprimer_rubrique' => 'Izbrisi ovu rubriku',
'lien_tout_deplier' => 'Sve otvoriti',
'lien_tout_replier' => 'Sve zatvoriti',
'lien_tout_supprimer' => 'Tout supprimer', # NEW
'lien_trier_nom' => 'Poredaj po imenu',
'lien_trier_nombre_articles' => 'Poredaj po broju clanaka',
'lien_trier_statut' => 'Poredaj po statusu',
'lien_voir_en_ligne' => 'POGLEDAJ ONLINE:',
'logo_article' => 'LOGOTIP CLANKA',
'logo_auteur' => 'LOGOTIP AUTORA',
'logo_breve' => 'LOGOTIP KRATKE PORUKE',
'logo_mot_cle' => 'LOGOTIP KLJUCNE RIJECI',
'logo_rubrique' => 'LOGOTIP RUBRIKE',
'logo_site' => 'LOGOTIP STRANICE',
'logo_standard_rubrique' => 'STANDARDNI LOGOTIP ZA RUBRIKE',
'logo_survol' => 'HOVERING LOGO',

// M
'menu_aide_installation_choix_base' => 'Biranje vase baze',
'module_fichier_langue' => 'Jezicni dokument',
'module_raccourci' => 'Precica',
'module_texte_affiche' => 'Prikazani tekst',
'module_texte_explicatif' => 'Mozete dodati sljedece precice u obrasce vase javne stranice. One ce biti automatski prevedene u razne jezike, za koje postoje jezicni dokumenti.',
'module_texte_traduction' => 'Jezicni dokument &laquo;&nbsp;@module@&nbsp;&raquo; je na raspolaganju u:',
'mois_non_connu' => 'nepoznato',

// N
'nouvelles_versions' => 'De nouvelles versions de SPIP sont disponibles', # NEW

// O
'onglet_contenu' => 'Contenu', # NEW
'onglet_declarer_une_autre_base' => 'D&eacute;clarer une autre base', # NEW
'onglet_discuter' => 'Discuter', # NEW
'onglet_documents' => 'Documents', # NEW
'onglet_interactivite' => 'Interactivit&eacute;', # NEW
'onglet_proprietes' => 'Propri&eacute;t&eacute;s', # NEW
'onglet_repartition_actuelle' => 'Aktuelno',
'onglet_sous_rubriques' => 'Sous-rubriques', # NEW
'ortho_ajouter_ce_mot' => 'Dodaj rijec u rijecnik',
'ortho_aucune_suggestion' => 'Nije pronadjena ni jedna sugestija za ovu rijec.',
'ortho_avis_privacy' => 'Provjera pravopisa je integrisana u SPIP. Svaki put kad aktivirate ovu funkciju, procitajte sljedeci odlomak:',
'ortho_avis_privacy2' => 'Da bi se provjerio pravopis jednog teksta, ova stranica ce poslati listu rijeci na jedan od externih "pravopisnih servera", koji su vam pruzeni na  raspolaganje od strane raznih clanova SPIP komune. Rijeci ce  biti poslane u pogresnom rasporedu da bi vam osigurali minimum  sigurnosti. Ako su vasi podaci povjerljivi, ne aktivirajte ovu opciju (i odmah povucite vase informacije sa Web-a).',
'ortho_ce_mot_connu' => 'Ova rijec je dio rijecnika stranice.',
'ortho_dico_absent' => 'Nije pronadjen ni jedan rijecnik za ovaj jezik',
'ortho_mode_demploi' => 'Rijeci koje nisu prepoznate, podvucene  su crvenom bojom. Mozete kliknuti na svaku rijec i izabrati  neku od prijedloga za ispravku.',
'ortho_mots_a_corriger' => 'rijeci za ispraviti',
'ortho_orthographe' => 'Pravopis',
'ortho_supprimer_ce_mot' => 'Odstrani ovu rijec iz rijecnika',
'ortho_trop_de_fautes' => 'Paznja: vas tekst sadrzi previse gresaka. Nijedna ispravka nije predlozena da bi se sprijecilo preopterecenje sistema.',
'ortho_verif_impossible' => 'Sistem ne moze provjeriti pravopis ovog teksta.',
'ortho_verifier' => 'Provjera pravopisa',

// P
'page_pas_proxy' => 'Cette page ne doit pas passer par le proxy', # NEW
'pas_de_proxy_pour' => 'Au besoin, indiquez les machines ou domaines pour lesquels ce proxy ne doit pas s\'appliquer (par exemple&nbsp;: @exemple@)', # NEW
'plugin_charge_paquet' => 'Chargement du paquet @name@', # NEW
'plugin_charger' => 'T&#233;l&#233;charger', # NEW
'plugin_erreur_charger' => 'erreur&nbsp;: impossible de charger @zip@', # NEW
'plugin_erreur_droit1' => 'Le r&#233;pertoire <code>@dest@</code> n\'est pas accessible en &#233;criture.', # NEW
'plugin_erreur_droit2' => 'Veuillez v&#233;rifier les droits sur ce r&#233;pertoire (et le cr&#233;er le cas &#233;ch&#233;ant), ou installer les fichiers par FTP.', # NEW
'plugin_erreur_zip' => 'echec pclzip&nbsp;: erreur @status@', # NEW
'plugin_etat_developpement' => 'u razvoju',
'plugin_etat_experimental' => 'experimentalno',
'plugin_etat_stable' => 'stabilno',
'plugin_etat_test' => 'testira se',
'plugin_impossible_activer' => 'Impossible d\'activer le plugin @plugin@', # NEW
'plugin_info_automatique1' => 'Si vous souhaitez autoriser l\'installation automatique des plugins, veuillez&nbsp;:', # NEW
'plugin_info_automatique1_lib' => 'Si vous souhaitez autoriser l\'installation automatique de cette librairie, veuillez&nbsp;:', # NEW
'plugin_info_automatique2' => 'cr&#233;er un r&#233;pertoire <code>@rep@</code>&nbsp;;', # NEW
'plugin_info_automatique3' => 'v&#233;rifier que le serveur est autoris&#233; &#224; &#233;crire dans ce r&#233;pertoire.', # NEW
'plugin_info_automatique_creer' => '&#224; cr&#233;er &#224; la racine du site.', # NEW
'plugin_info_automatique_exemples' => 'exemples&nbsp;:', # NEW
'plugin_info_automatique_ftp' => 'Vous pouvez installer des plugins, par FTP, dans le r&#233;pertoire <tt>@rep@</tt>', # NEW
'plugin_info_automatique_lib' => 'Certains plugins demandent aussi &#224; pouvoir t&#233;l&#233;charger des fichiers dans le r&#233;pertoire <code>lib/</code>, &#224; cr&#233;er le cas &#233;ch&#233;ant &#224; la racine du site.', # NEW
'plugin_info_automatique_liste' => 'Vos listes de plugins&nbsp;:', # NEW
'plugin_info_automatique_liste_officielle' => 'les plugins officiels', # NEW
'plugin_info_automatique_liste_update' => 'Mettre &#224; jour les listes', # NEW
'plugin_info_automatique_ou' => 'ou...', # NEW
'plugin_info_automatique_select' => 'S&#233;lectionnez ci-dessous un plugin&nbsp;: SPIP le t&#233;l&#233;chargera et l\'installera dans le r&#233;pertoire <code>@rep@</code>&nbsp;; si ce plugin existe d&#233;j&#224;, il sera mis &#224; jour.', # NEW
'plugin_info_extension_1' => 'Les extensions ci-dessous sont charg&#233;es et activ&#233;es dans le r&#233;pertoire @extensions@.', # NEW
'plugin_info_extension_2' => 'Elles ne sont pas d&#233;sactivables.', # NEW
'plugin_info_telecharger' => '&#224; t&#233;l&#233;charger depuis @url@ et &#224; installer dans @rep@', # NEW
'plugin_librairies_installees' => 'Librairies install&#233;es', # NEW
'plugin_necessite_lib' => 'Ce plugin n&#233;cessite la librairie @lib@', # NEW
'plugin_necessite_plugin' => 'N&eacute;cessite le plugin @plugin@ en version @version@ minimum.', # NEW
'plugin_necessite_spip' => 'N&eacute;cessite SPIP en version @version@ minimum.', # NEW
'plugin_source' => 'source:&nbsp;', # NEW
'plugin_titre_automatique' => 'Installation automatique', # NEW
'plugin_titre_automatique_ajouter' => 'Ajouter des plugins', # NEW
'plugin_titre_installation' => 'Installation du plugin @plugin@', # NEW
'plugin_zip_active' => 'Continuez pour l\'activer', # NEW
'plugin_zip_adresse' => 'indiquez ci-dessous l\'adresse d\'un fichier zip de plugin &#224; t&#233;l&#233;charger, ou encore l\'adresse d\'une liste de plugins.', # NEW
'plugin_zip_adresse_champ' => 'Adresse du plugin ou de la liste&nbsp;', # NEW
'plugin_zip_content' => 'Il contient les fichiers suivants (@taille@),<br />pr&#234;ts &#224; installer dans le r&#233;pertoire <code>@rep@</code>', # NEW
'plugin_zip_installe_finie' => 'Le fichier @zip@ a &#233;t&#233; d&#233;compact&#233; et install&#233;.', # NEW
'plugin_zip_installe_rep_finie' => 'Le fichier @zip@ a &#233;t&#233; d&#233;compact&#233; et install&#233; dans le r&#233;pertoire @rep@', # NEW
'plugin_zip_installer' => 'Vous pouvez maintenant l\'installer.', # NEW
'plugin_zip_telecharge' => 'Le fichier @zip@ a &#233;t&#233; t&#233;l&#233;charg&#233;', # NEW
'plugins_actif_aucun' => 'Aucun plugin activ&#233;.', # NEW
'plugins_actif_un' => 'Un plugin activ&#233;.', # NEW
'plugins_actifs' => '@count@ plugins activ&#233;s.', # NEW
'plugins_actifs_liste' => 'Plugins actifs', # NEW
'plugins_compte' => '@count@ plugins', # NEW
'plugins_disponible_un' => 'Un plugin disponible.', # NEW
'plugins_disponibles' => '@count@ plugins disponibles.', # NEW
'plugins_erreur' => 'Erreur dans les plugins : @plugins@', # NEW
'plugins_liste' => 'Plugin lista',
'plugins_liste_extensions' => 'Extensions', # NEW
'plugins_recents' => 'Plugins r&eacute;cents.', # NEW
'plugins_vue_hierarchie' => 'Hi&eacute;rarchie', # NEW
'plugins_vue_liste' => 'Liste', # NEW
'protocole_ldap' => 'Version du protocole :', # NEW

// R
'repertoire_plugins' => 'Directorij:',

// S
'sans_heure' => 'sans heure', # NEW
'sauvegarde_fusionner' => 'Fusionner la base actuelle et la sauvegarde', # NEW
'sauvegarde_fusionner_depublier' => 'D&eacute;publier les objets fusionn&eacute;s', # NEW
'sauvegarde_url_origine' => 'Eventuellement, URL du site d\'origine :', # NEW
'statut_admin_restreint' => '(ograniceni admin)',
'syndic_choix_moderation' => 'Sta treba uraditi sa sljedecim linkovima sa ove stranice?',
'syndic_choix_oublier' => 'Sta treba uraditi sa linkovima koji vise nisu prisutni u dokumentu sindikacije?',
'syndic_choix_resume' => 'Neke stranice nude na raspolaganje cjelokupni tekst clanaka. Ako je taj dostupan, zelite li pristupiti sindikaciji:',
'syndic_lien_obsolete' => 'zastarijeli link',
'syndic_option_miroir' => 'atomatski blokiraj',
'syndic_option_oubli' => 'izbrisi (poslije  @mois@&nbsp;mmjesec/a/i)',
'syndic_option_resume_non' => 'kompletni sadrzaj clanaka (u  HTML formatu)',
'syndic_option_resume_oui' => 'jednostavni rezime (u formi teksta)',
'syndic_options' => 'Opcije sindikacije:',

// T
'taille_cache_image' => 'Slike koje SPIP automatski izracunava (vinjete dokumenata, naslove predstavljene u grafickoj formi, matematicke funkcije u TeX formatu ...) zauzimaju u @dir@  repertoaru total od @taille@.',
'taille_cache_infinie' => 'Ova stranica ne ukljucuje ogranicenje velicine u repertoaru <code>CACHE/</code>.', # MODIF
'taille_cache_maxi' => 'SPIP pokusava ograniciti velicinu repertoara <code>CACHE/</code> ove stranice za oko <b>@octets@</b> podataka.', # MODIF
'taille_cache_octets' => 'Aktuelna velicina kesa je @octets@.',
'taille_cache_vide' => 'Kes je prazan.',
'taille_repertoire_cache' => 'Aktuelna velicina kesa',
'text_article_propose_publication' => 'Clanak predlozen za objavljivanje. Ne oklijevajte da date vase misljenje u forumu dodanom ovom clanku (na dnu ove strane).', # MODIF
'text_article_propose_publication_forum' => 'N\'h&eacute;sitez pas &agrave; donner votre avis gr&acirc;ce au forum attach&eacute; &agrave; cet article (en bas de page).', # NEW
'texte_acces_ldap_anonyme_1' => 'Neki LDAP serveri ne prihvataju ni jedan anonimni pristup. U tom slucaju je potrebno odrediti identifikatora za inicijalni pristup, da bi zatim postojala mogucnost pretrage informacija u direktoriju. U vecini slucajeva, sljedeca polja mogu ostati prazna',
'texte_admin_effacer_01' => 'Ova komanda ce izbrisati <i>sav</i> sadrzaj baze podataka, ukljucujuci <i>sve</i> pristupe urednika i administratora. Prije nego je pokrenete,  trebate pokrenuti reinstalaciju pristupa SPIP-u da biste kreirali novu bazu, kao i prvi pristup administratora.',
'texte_admin_effacer_stats' => 'Cette commande efface toutes les donn&eacute;es li&eacute;es aux statistiques de visite du site, y compris la popularit&eacute; des articles.', # NEW
'texte_admin_tech_01' => 'Ova opcija vam omogucuje pohranjivanja sadrzaja baze u dokument koji ce biti pohranjen u  direktoriju @dossier@. Ne zaboravite sacuvati sve sto  obuhvata IMG repertoar, sto ukljucuje slike i dokumente koristene u clancima i rubrikama.', # MODIF
'texte_admin_tech_02' => 'Paznja: Ovo pohranjivanje ne moze biti obnovljeno, OSIM na stranici koja je instalirana sa istom verzijom SPIP-a. Nije preporuceno praznjenje baze, ako namjerevate reinstalaciju backup-a nakon update-a  ... Konsultujte <a  href="@spipnet@">SPIP  dokumentaciju</a>.', # MODIF
'texte_admin_tech_03' => 'Mozete izabrati pohranjivanje dokumenta u kompresovanoj formi, da bi ste skratili transfer kod vas ili nekog servera za pohranjivanje i da bi ste smanjili prostor na maticnoj ploci. ',
'texte_admin_tech_04' => 'Dans un but de fusion avec une autre base, vous pouvez limiter la sauvegarde &agrave; la rubrique: ', # NEW
'texte_adresse_annuaire_1' => '(Ako je vas direktorij instaliran na istoj masini kao ova web stranica, vjerovatno se radi o localhost-u.)',
'texte_ajout_auteur' => 'Sljedeci autor je dodan clanku:',
'texte_annuaire_ldap_1' => 'Ako imate pristup jednom (LDAP) direktoriju, mozete ga koristiti za automatsko importovanje korisnika u SPIP.',
'texte_article_statut' => 'Ovaj clanak je:',
'texte_article_virtuel' => 'Virtuelni clanak',
'texte_article_virtuel_reference' => '<b>Virtuelni clanak:</b> clanak je preporucen na vasoj SPIP stranici, ali apreusmjeren na drugi URL. Da bi ste sprijecili preusmjeravanje, izbrisite nize prikazani URL.',
'texte_aucun_resultat_auteur' => 'Nema rezultata za"@cherche_auteur@"',
'texte_auteur_messagerie' => 'Ova stranica vam moze permanentno ukazivati na listu konektovanih urednika, sto vam omogucuje online razmjenu poruka. Mozete odluciti da se ne pojavljujete na ovoj listi (nevidljivi ste za druge korisnike).',
'texte_auteur_messagerie_1' => 'Ova stranica vam dozvoljava razmjenu poruka i formiranje foruma za diskusiju izmedju ucesnika na stranici. Mozete odluciti da ne ucestvujete u ovim  promjenama.',
'texte_auteurs' => 'AUTORI',
'texte_breves' => 'Kratke poruke su kratki i jednostavni tekstovi, koji dozvoljavaju brzo postavljanje preciznih informacija, obradjivanje casopisa, kalendara dogadjaja...',
'texte_choix_base_1' => 'Izaberite vasu bazu:',
'texte_choix_base_2' => 'SQL server sadrzi vise baza podataka.', # MODIF
'texte_choix_base_3' => '<b>Izaberite</b> Ispod one koja vam je dodjeljena od vaseg kompjutera:', # MODIF
'texte_choix_table_prefix' => 'Pr&eacute;fixe des tables&nbsp;:', # NEW
'texte_commande_vider_tables_indexation' => 'Koristite ovu komandu da biste ispraznili tabele za indeksiranje, koje koriste motori za pretragu integrisani u SPIP. To ce vam  omoguciti da dobijete na prostoru na disku .',
'texte_comment_lire_tableau' => 'Rang clanka po popularnosti je naznacen u margini; popularnost clanka (broj dnevnih posjeta, ako se ritam konsultacije odrzava) i broj primljenih posjeta u polju koje se pojavi kada misem predjete preko naslova.',
'texte_compacter_avertissement' => 'Attention &#224; ne pas activer ces options durant le d&#233;veloppement de votre site : les &#233;l&#233;ments compact&#233;s perdent toute lisibilit&#233;.', # NEW
'texte_compacter_script_css' => 'SPIP peut compacter les scripts javascript et les feuilles de style CSS, pour les enregistrer dans des fichiers statiques ; cela acc&#233;l&#232;re l\'affichage du site.', # NEW
'texte_compresse_ou_non' => '(Ovo moze biti kompresovano ili ne)',
'texte_compresseur_page' => 'SPIP peut compresser automatiquement chaque page qu\'il envoie aux
visiteurs du site. Ce r&#233;glage permet d\'optimiser la bande passante (le
site est plus rapide derri&#232;re une liaison &#224; faible d&#233;bit), mais
demande plus de puissance au serveur.', # NEW
'texte_compte_element' => '@count@ element',
'texte_compte_elements' => '@count@ elementi',
'texte_config_groupe_mots_cles' => 'Da li zelite aktivirati naprednu konfiguraciju kljucnih rijeci, sto znaci da je moguce izabrati jednu rijec po grupi, da je jedna grupa vazna...?', # MODIF
'texte_conflit_edition_correction' => 'Veuillez contr&#244;ler ci-dessous les diff&#233;rences entre les deux versions du texte&nbsp;; vous pouvez aussi copier vos modifications, puis recommencer.', # NEW
'texte_connexion_mysql' => 'Provjerite informacije koje ste dobili od vaseg kompjutera: Trebate pronaci da li vas kompjuter podrzava SQL i kodove za konekciju na SQL  server.', # MODIF
'texte_contenu_article' => '(Sadrzaj clanka u nekoliko rijeci.)',
'texte_contenu_articles' => 'Prema rasporedu koji je prihvacen za vasu stranicu, mozete odluciti da se neki elementi clanaka ne koriste. Koristite se sa nize prikazanom listom i naznacite koji su elementi dostupni.',
'texte_crash_base' => 'Ako je vasa baza podataka pala, mozete pokusati automatsku popravku.',
'texte_creer_rubrique' => 'Prije pisanja clanaka,<br /> trebate kreirati rubriku.', # MODIF
'texte_date_creation_article' => 'DATUM NASTANKA CLANKA:',
'texte_date_publication_anterieure' => 'Datum proslog uredjivanja:',
'texte_date_publication_anterieure_nonaffichee' => 'Ne prikazuj datum proslog uredjivanja.',
'texte_date_publication_article' => 'DATUM OBJAVLJIVANJA:',
'texte_descriptif_petition' => 'Opis peticije',
'texte_descriptif_rapide' => 'Brzi opis',
'texte_documents_joints' => 'Mozete odobriti dodavanje dokumenata (birokratskih dokumenata, slika, multimedija, itd.) clancima i/ili rubrikama. Ti dokumenti mogu zatim biti preporuceni u clanku ili postavljeni odvojeno.', # MODIF
'texte_documents_joints_2' => 'Ova postavka ne sprijecava direktno unosenje slika u clanke.',
'texte_effacer_base' => 'Izbrisati SPIP bazu podataka',
'texte_effacer_donnees_indexation' => 'Izbrisati podatke indexiranja',
'texte_effacer_statistiques' => 'Effacer les statistiques', # NEW
'texte_en_cours_validation' => 'Dole navedeni clanci i kratke poruke su predlozene za publikaciju. Vase misljenje mozete iznijeti u njima prikljucenim forumima.', # MODIF
'texte_en_cours_validation_forum' => 'N\'h&eacute;sitez pas &agrave; donner votre avis gr&acirc;ce aux forums qui leur sont attach&eacute;s.', # NEW
'texte_enrichir_mise_a_jour' => 'Mozete obogatiti izgled vaseg teksta na stranici, koristeci se &laquo;&nbsp;tipogrfskim  precicama&nbsp;&raquo;.',
'texte_fichier_authent' => '<b>Treba li SPIP kreirati specijalne dokumente <tt>.htpasswd</tt> i  <tt>.htpasswd-admin</tt> u repertoaru @dossier@ ?</b><p> Ti dokumenti vam omogucuju zabranu pristupa autorima  i administratorima na drugim mjestima vase stranice (npr.  eksterni program za statistike).</p><p>  Ako od ovoga nemate  nikakve koristi, mozete ostaviti standardnu vrijednost za ovu  opciju (nema kreacije dokumenata).</p>', # MODIF
'texte_informations_personnelles_1' => 'Sistem ce sada kreirati  personalizovan pistup stranici.',
'texte_informations_personnelles_2' => '(Napomena: ako se radi o reinstalaciji i ako vas pristup uvijek funkcionise, mozete',
'texte_introductif_article' => '(Uvodni tekst u clanak.)',
'texte_jeu_caractere' => 'Ova opcija je korisna ako vasa  stranica treba postavljati tekstove sa alfabetom (ukljucujuci  njegove derivate) koji nije romanski (ili  &laquo;&nbsp;okcidentalni&nbsp;&raquo;). U tom slucaju je  pozeljno promijeniti standardnu postavku u odgovarajuci set  karaktera; u svakum slucaju vam savjetujemo da napravite  testove i pronadjete zadovoljavajuce rijesenje. Ako izmlijenite  ovaj parametar, ne zaboravite javnu stranicu prilagoditi  izmjenama (balise <tt>#CHARSET</tt>).',
'texte_jeu_caractere_2' => 'Ova postavka nema retroaktivni  efekat. Radi toga, vec uneseni tekstovi mogu radi biti pogresno  prikazani uslijed izmjene postavke. U svako slucaju, mozete se  bez gubitka vratiti na prethodnu postavku.',
'texte_jeu_caractere_3' => 'Votre site est actuellement install&eacute; dans le jeu de caract&egrave;res&nbsp;:', # NEW
'texte_jeu_caractere_4' => 'Si cela ne correspond pas &agrave; la r&eacute;alit&eacute; de vos donn&eacute;es (suite, par exemple, &agrave; une restauration de base de donn&eacute;es), ou si <em>vous d&eacute;marrez ce site</em> et souhaitez partir sur un autre jeu de caract&egrave;res, veuillez indiquer ce dernier ici&nbsp;:', # NEW
'texte_jeu_caractere_conversion' => 'Note&nbsp;: vous pouvez d&eacute;cider de convertir une fois pour toutes l\'ensemble des textes de votre site (articles, br&egrave;ves, forums, etc.) vers l\'alphabet <tt>utf-8</tt>, en vous rendant sur <a href="@url@">la page de conversion vers l\'utf-8</a>.', # NEW
'texte_lien_hypertexte' => '(Ako se vasa poruka odnosi na  clanak objavljen na web-u ili stranicu koja pruza vise  informacija, naznacite naziv stranice i njenu URL adresu.)',
'texte_liens_sites_syndiques' => 'Linkovi izvedeni iz sindikovanih stranica mogu a priori biti blokirani; dole prikazana postavka  je standardna postavka sindikovanih stranica prije njihove kreacije. U svakom slucaju je moguce pojedinacno deblokirati  svaki link ili, stranicu po stranicu, blokirati linkove koji  dolaze sa odredjene lokacije.',
'texte_login_ldap_1' => '(Ostaviti prazno za anonimni pristup ili unjeti kompletnu putanju, npr. &laquo;&nbsp;<tt>uid=dupont,  ou=users, dc=mon-domaine, dc=com</tt>&nbsp;&raquo;.)',
'texte_login_precaution' => 'Paznja! Ovo je login kojim ste trenutno konektovani. Pazljivo se koristite ovim  formularom...',
'texte_message_edit' => 'Paznja: ovu poruku moze imijeniti svaki administrator stranice, a vidljiva je svim urednicima.  Koristite se najavama samo da biste najavili vazne dogadjaje  zivota stranice.',
'texte_messagerie_agenda' => 'Une messagerie permet aux r&#233;dacteurs du site de communiquer entre eux directement dans l&#8217;espace priv&#233; du site. Elle est associ&#233;e &#224; un agenda.', # NEW
'texte_messages_publics' => 'Javne poruke clanka:',
'texte_mise_a_niveau_base_1' => 'Upravo ste obnovili SPIP dokumente. Sada je potrebna nadogrdnja baze podataka.',
'texte_modifier_article' => 'Izmijeni clanak:',
'texte_moteur_recherche_active' => '<b>Motor za pretragu je  aktivan.</b> Koristite se ovom komandom ako zelite pristupiti brze reindeksacije (npr. nakon pohranjivanja).  Dokumenti koji su izmijenjeni na normalan nacin (prema SPIP rasoredu) su reindeksovani automatski: dakle, ova komanda je korisna samo u iznimnim slucajevima.',
'texte_moteur_recherche_non_active' => 'Motor za pretragu nije aktiviran.',
'texte_mots_cles' => 'Kljucne rijeci omogucuju kreiranje tematskih veza izmedju vasih clanaka, neovisno o njihovom  mjestu u rubrikama. Tako mozete obogatiti navigaciju na vasoj  stranici i cak koristiti ovu opciju personalizovali prezentaciju clanaka u vasim obrascima.',
'texte_mots_cles_dans_forum' => 'Da li zelite odobriti koristenje kljucnih rijeci (posjetioci mogu izabrati iste) u  forumima javne stranice? (Paznja: ova opcija relativno slozena za ispravno koristenje.)', # MODIF
'texte_multilinguisme' => 'Ako zelita obradjivati clanke na vise jezika, sa kompleksnom navigacijom, u organizaciju vase  stranice mozete dodati meni za odabir jezika u clancima i/ili  rubrikama.',
'texte_multilinguisme_trad' => 'Svakako mozete aktivirati sistem sa obradjivanje linkova izmedju razlicitih prevoda  clanaka.',
'texte_non_compresse' => '<i>nije kompresovan</i> (vas server ne podrzava ovu funkciju)',
'texte_non_fonction_referencement' => 'Mozete izabrati da ne koristite ovu automatsku funkciju i sami naznaciti elemente vezane za ovu stranicu...',
'texte_nouveau_message' => 'Nova poruka',
'texte_nouveau_mot' => 'Nova rijec',
'texte_nouvelle_version_spip_1' => 'Instalirali ste novu verziju SPIP-a.',
'texte_nouvelle_version_spip_2' => 'Ovoj verziji je potrebno obnavljanje kompletnije od uobicajenog. Ako ste webmaster stranice, izbrisite dokument <tt>inc_connect.php3</tt> iz  repertoara <tt>ecrire</tt> i ponovo otpocnite instalaciju da  biste obnovili parametre konekcije sa bazom podataka.<p>  (Napomena: ako ste zaboravili parametre vase konekcije  pogledajte dokument <tt>inc_connect.php3</tt> prije nego ga  izbrisete...)</p>', # MODIF
'texte_operation_echec' => 'Vratite se na prethodnu stranu, izaberite drugu bazu ili napravite novu. Provjerite podatke  koje vam je dao vas kompjuter.',
'texte_plus_trois_car' => 'vise od tri karaktera',
'texte_plusieurs_articles' => 'Pronadjeno vise autora za "@cherche_auteur@":',
'texte_port_annuaire' => '(Naznacena standardna vrijednost odgovara u vecini slucajeva.)',
'texte_presente_plugin' => 'Cette page liste les plugins disponibles sur le site. Vous pouvez activer les plugins n&eacute;cessaires en cochant la case correspondante.', # NEW
'texte_proposer_publication' => 'Kada zavrsite vas clanak,<br /> mozete predloziti njegovo objavljivanje.', # MODIF
'texte_proxy' => 'U odredjenim slucajevima (intranet, zasticene  mreze...), koristenje <i>proxy HTTP</i> moze biti neophodno za dostizanje sindikovanih stranica. Ako je potrebno, naznacite adresu u sljedecoj formi <tt><html>http://proxy:8080</html></tt>. U vecini slucajeva, ovo polje mozete ostaviti prazno.', # MODIF
'texte_publication_articles_post_dates' => 'Kako se SPIP treba ponasati prema clancima ciji je datum objavljivanja odredjen za buducnost? ',
'texte_rappel_selection_champs' => '[Ne zaboravite ispravno izabrati ovo polje.]',
'texte_recalcul_page' => 'Ako zelite preracunati samo jednu stranu, predjite u javni prostor i koristite &laquo; preracunati &raquo;.',
'texte_recapitiule_liste_documents' => 'Ova strana ponavlja spisak dokumenata koje ste postavili u rubrikama. Da biste izmijenili informacije svakog dokumenta, pratite link do strane sa njegovom rubrikom.',
'texte_recuperer_base' => 'Popravi bazu podataka',
'texte_reference_mais_redirige' => 'clanak je preporucen u vasoj SPIP stranici, ali je preusmjeren na drugi URL.',
'texte_referencement_automatique' => '<b>Automatska preporuka stranice</b><br />Mozete brzo preporuciti web stranicu, tako sto cete naznaciti zeljenu URL adresu ili adresu njenog backend dokumenta. SPIP ce automatski sakupiti informacije vezane za tu stranicu (naslov, opis...).', # MODIF
'texte_referencement_automatique_verifier' => 'Veuillez v&eacute;rifier les informations fournies par <tt>@url@</tt> avant d\'enregistrer.', # NEW
'texte_requetes_echouent' => '<b>Ako odredzeni SQL zahtijevi sistematski i bez ociglednog razloga ne uspijevaju, moguce je da je problem u samoj bazi podataka.</b><p> SQL raspolaze mogucnosti popravljanja njegovih tabela, ako su one slucajno ostecene. Ovdje mozete isprobati popravku; u slucaju neuspijeha, sacuvajte kopiju prikaza na monitoru, koja mozda sadrzi naznake problema...</p><p> Ako se problem nastavi, kontaktirajte vas hosting servis.</p>', # MODIF
'texte_restaurer_base' => 'Obnoviti sadrzaj pohranjivanja baze',
'texte_restaurer_sauvegarde' => 'Ova opcija vam omogucava obnavljanje ranije izvedenog pohranjivanja baze. U tom slucaju, dokument koji, sadrzi pohranjeni materijal, se treba nalaziti u repertoaru @dossier@. Budite oprezni sa ovom funkcijom: <b>moguce izmjene i gubitci su nepovratni.</b>', # MODIF
'texte_sauvegarde' => 'Snimiti sadrzj baze',
'texte_sauvegarde_base' => 'Snimiti bazu',
'texte_sauvegarde_compressee' => 'Pohranjivanje ce se izvrsiti u nekompresovanom dokumentu @fichier@.', # MODIF
'texte_selection_langue_principale' => 'Mozete izabrati &laquo;&nbsp;glavni jezik&nbsp;&raquo; stranice. Taj izbor vas (na srecu!) ne obavezuje na pisanje clanaka na tom jeziku, ali dozvoljava odredjivanje:
\\tab <ul><li> standardni format datuma na javnoj stranici;</li>
\\tab <li> prirodu tipografskog motora koj ce SPIP koristriti za izradu tekstova;</li>
\\tab <li> jezik koji ce se koristiti u formularima javne stranice;</li>
\\tab <li> standardni jezik, prisutan na privatnoj stranici.</li></ul>',
'texte_signification' => 'Tamne trake predstavljaju kulminativne zapise (ukupan broj podrubrika), svijetle trake predstavljaju ukupan broj posjeta za svaku rubriku.',
'texte_sous_titre' => 'Podnaslov',
'texte_statistiques_visites' => '(tamne trake:  nedjelja / tamna kriva: prosjecni nivo)',
'texte_statut_attente_validation' => 'na cekanju za ovjeru',
'texte_statut_publies' => 'objavljeni',
'texte_statut_refuses' => 'odbijeni',
'texte_suppression_fichiers' => 'Koristite se ovom komandom da biste sve prisutne dokumente u SPIP kes. To omogucuje npr. izazivanje preracunavanja svih strana, u slucaju da ste izveli vazne izmjene grafizma ili strukture stranice.',
'texte_sur_titre' => 'Nadnaslov',
'texte_syndication' => 'Moguce je automatsko otkrivanje spiska novosti, ako web stranica to dozvoljava. Zato trebate aktivirati sindikaciju\\tab <blockquote><i>Odredjeni hosting servisi dezaktiviraju tu funkciju; u tom slucaju ne mozete koristiti sindikaciju sadrzaja na vasoj stranici.</i></blockquote>', # MODIF
'texte_table_ok' => ':ova tabela je OK.',
'texte_tables_indexation_vides' => 'Tabele indeksacije motora su prazne.',
'texte_tentative_recuperation' => 'Pokusaj popravke',
'texte_tenter_reparation' => 'Pokusati popravljanje baze podataka',
'texte_test_proxy' => 'Da bi ste probali ovaj proxy, ovdje naznacite adresu (web stranice) koju zelite testirati.',
'texte_titre_02' => 'Naslov:',
'texte_titre_obligatoire' => '<b>Naslov</b> [Obavezan]', # MODIF
'texte_travail_article' => '@nom_auteur_modif@ ostaje @date_diff@ minuta za rad na ovom clanku',
'texte_travail_collaboratif' => 'Ako je uobicajeno da vise urednika radi na istom clanku, sistem moze postavljati posljednje &laquo;&nbsp;otvarane&nbsp;&raquo; clanke, da bi se izbjegle simultane izmjene. Ova opcija je standardno iskljucena, da bi se izbjeglo postavljanje neodgovarajucih poruka upozorenja.',
'texte_trop_resultats_auteurs' => 'Previse rezultata za pretragu "@cherche_auteur@" ; predefinisite opcije pretrazivanja.',
'texte_type_urls' => 'Vous pouvez choisir ci-dessous le mode de calcul de l\'adresse des pages.', # NEW
'texte_type_urls_attention' => 'Attention ce r&eacute;glage ne fonctionnera que si le fichier @htaccess@ est correctement install&eacute; &agrave; la racine du site.', # NEW
'texte_unpack' => 'download posljednje verzije',
'texte_utilisation_moteur_syndiques' => 'Ako koristitie motor pretrage koji je integrisan u SPIP, mozete na dva razlicita nacina izvesti pretragu na sindikovanim stranicama i clancima. <br /><img  src=\\"puce.gif\\"> Najjednostavnije je pretrazivati samo naslove i opise clanaka. <br /><img src=\\"puce.gif\\"> Mnogo jaca metoda dozvoljava SPIP-u da trazi unutar tekstova preporucenih sranica. Dakle, ako preporucite neku stranicu, SPIP ce izvrsiti pretragu unutar samog teksta stranice.', # MODIF
'texte_utilisation_moteur_syndiques_2' => 'Ova metoda obavezuje SPIP da redovno posjecuje preporucene stranice, sto moze izazvati lahko usporavanje vase sopstvene stranice.',
'texte_vide' => 'prazno',
'texte_vider_cache' => 'Isprazniti kes',
'titre_admin_effacer' => 'Tehnicko odrzavanje',
'titre_admin_tech' => 'Tehnicko odrzavanje',
'titre_admin_vider' => 'Tehnicko odrzavanje',
'titre_articles_syndiques' => 'Sindikovani clanci, izvuceni iz ove stranice',
'titre_breves' => 'Kratke poruke',
'titre_cadre_afficher_article' => 'Prikazi clanke',
'titre_cadre_afficher_traductions' => 'Prikazi stanje prevoda za sljedece jezike:',
'titre_cadre_ajouter_auteur' => 'DODATI AUTORA:',
'titre_cadre_forum_administrateur' => 'Privatni forum za administratore',
'titre_cadre_forum_interne' => 'Interni forum',
'titre_cadre_interieur_rubrique' => 'U unutrasnjosti rubrike',
'titre_cadre_numero_auteur' => 'AUTOR BROJ',
'titre_cadre_signature_obligatoire' => '<b>Potpis</b>  [Obavezno]<br />', # MODIF
'titre_compacter_script_css' => 'Compactage des scripts et CSS', # NEW
'titre_compresser_flux_http' => 'Compression du flux HTTP', # NEW
'titre_config_contenu_notifications' => 'Notifications', # NEW
'titre_config_contenu_prive' => 'Dans l&#8217;espace priv&#233;', # NEW
'titre_config_contenu_public' => 'Sur le site public', # NEW
'titre_config_fonctions' => 'Konfiguracija stranice',
'titre_config_forums_prive' => 'Forums de l&#8217;espace priv&#233;', # NEW
'titre_config_groupe_mots_cles' => 'Konfiguracija grupa kljucnih rijeci',
'titre_configuration' => 'Konfiguracija stranice',
'titre_conflit_edition' => 'Conflit lors de l\'&#233;dition', # NEW
'titre_connexion_ldap' => 'Opcije: <b>Vasa LDAP konekcija</b>',
'titre_dernier_article_syndique' => 'Posljednji sindikovani clanci',
'titre_documents_joints' => 'Pridruzeni dokumenti',
'titre_evolution_visite' => 'Napredovanje posjeta',
'titre_forum_suivi' => 'Pracenje foruma',
'titre_gauche_mots_edit' => 'RIJEC BROJ:',
'titre_groupe_mots' => 'GRUPA RIJECI:',
'titre_langue_article' => 'JEZIK CLANKA',
'titre_langue_breve' => 'JEZIK KRATKE PORUKE',
'titre_langue_rubrique' => 'JEZIK RUBRIKE',
'titre_langue_trad_article' => 'JEZIK I PREVOD CLANKA',
'titre_les_articles' => 'CLANCI',
'titre_messagerie_agenda' => 'Messagerie et agenda', # NEW
'titre_mots_cles_dans_forum' => 'Kljucne rijeci u forumu javne stranice',
'titre_mots_tous' => 'Kljucne rijeci',
'titre_naviguer_dans_le_site' => 'Navigacija stranicom...',
'titre_nouveau_groupe' => 'Nova grupa',
'titre_nouvelle_breve' => 'Nova kratka poruka',
'titre_nouvelle_rubrique' => 'Nova rubrika',
'titre_numero_rubrique' => 'RUBRIKA BROJ:',
'titre_page_admin_effacer' => 'Tehnicko odrzavanje: brisanje baze',
'titre_page_articles_edit' => 'Izmjeni: @titre@',
'titre_page_articles_page' => 'Clanci',
'titre_page_articles_tous' => 'Cijela stranica',
'titre_page_auteurs' => 'Posjetioci',
'titre_page_breves' => 'Kratke poruke',
'titre_page_breves_edit' => 'Izmijeni kratku poruku: &laquo;  @titre@ &raquo;',
'titre_page_calendrier' => 'Kalendar @nom_mois@ @annee@',
'titre_page_config_contenu' => 'Konfiguracija stranice',
'titre_page_config_fonctions' => 'Konfiguracija stranice',
'titre_page_configuration' => 'Konfiguracija stranice',
'titre_page_controle_petition' => 'Pracenje peticija',
'titre_page_delete_all' => 'cjelokupno i nepovratno otklanjanje',
'titre_page_documents_liste' => 'Dokumenti rubrike',
'titre_page_forum' => 'Forum administratora',
'titre_page_forum_envoi' => 'Posalji poruku',
'titre_page_forum_suivi' => 'Pracenje foruma',
'titre_page_index' => 'Vas privatni prostor',
'titre_page_message_edit' => 'Napisi poruku',
'titre_page_messagerie' => 'Vas transfer poruka',
'titre_page_mots_tous' => 'Kljucne rijeci',
'titre_page_recherche' => 'Rezultati pretrage @recherche@',
'titre_page_sites_tous' => 'Preporucene stranice',
'titre_page_statistiques' => 'Statistike po rubrikama',
'titre_page_statistiques_messages_forum' => 'Messages de forum', # NEW
'titre_page_statistiques_referers' => 'Statistike (linkovi unosenja)',
'titre_page_statistiques_signatures_jour' => 'Nombre de signatures par jour', # NEW
'titre_page_statistiques_signatures_mois' => 'Nombre de signatures par mois', # NEW
'titre_page_statistiques_visites' => 'Statistike posjeta',
'titre_page_upgrade' => 'Postavljanje SPIP-a na aktuelni nivo',
'titre_publication_articles_post_dates' => 'Objavljivanje clanaka sa kasnijim datumom',
'titre_referencement_sites' => 'Sindikacija i preporucivanje stranica',
'titre_referencer_site' => 'Preporuciti stranicu:',
'titre_rendez_vous' => 'SASTANAK:',
'titre_reparation' => 'Popravka',
'titre_site_numero' => 'STRANICA BROJ:',
'titre_sites_proposes' => 'Predlozene stranice',
'titre_sites_references_rubrique' => 'Preporucene stranice u ovoj rubrici',
'titre_sites_syndiques' => 'Sindikovane stranice',
'titre_sites_tous' => 'Preporucene stranice',
'titre_suivi_petition' => 'Pracenje peticija',
'titre_syndication' => 'Sindikacija stranica',
'titre_type_urls' => 'Type d\'adresses URL', # NEW
'tls_ldap' => 'Transport Layer Security :', # NEW
'tout_dossier_upload' => 'Cjelokupan dosije @upload@',
'trad_article_inexistant' => 'Ne postoji clanak koji nosi ovaj broj.',
'trad_article_traduction' => 'Sve verzije ovog clanka:',
'trad_deja_traduit' => 'Ovaj clanak je vec prevod prethodnog clanka.', # MODIF
'trad_delier' => 'Ne vezati vise ovaj clanak za ove prevode',
'trad_lier' => 'Ovaj clanak je prevod clanka broj:',
'trad_new' => 'Napisati novi prevod ovog clanka',

// U
'upload_fichier_zip' => 'ZIP dokument',
'upload_fichier_zip_texte' => 'Dokument koji predlazete za upload, je ZIP dokument.',
'upload_fichier_zip_texte2' => 'Ovaj dokument moze biti:',
'upload_info_mode_document' => 'D&#233;poser cette image dans le portfolio', # NEW
'upload_info_mode_image' => 'Retirer cette image du portfolio', # NEW
'upload_limit' => 'Ovaj dokument je prevelik za server; dozvoljena maksimalna velicina za <i>upload</i> je @max@.',
'upload_zip_conserver' => 'Conserver l&#8217;archive apr&#232;s extraction', # NEW
'upload_zip_decompacter' => 'dekompresovan i svaki sadrzani dokument ce biti instaliran na stranicu. Dokumenti koji ce biti instalirani su:',
'upload_zip_telquel' => 'instaliran kakav jeste, u ZIP formatu;',
'upload_zip_titrer' => 'Titrer selon le nom des fichiers', # NEW
'utf8_convert_attendez' => 'Attendez quelques instants et rechargez cette page.', # NEW
'utf8_convert_avertissement' => 'Vous vous appr&ecirc;tez &agrave; convertir le contenu de votre base de donn&eacute;es (articles, br&egrave;ves, etc) du jeu de caract&egrave;res <b>@orig@</b> vers le jeu de caract&egrave;res <b>@charset@</b>.', # NEW
'utf8_convert_backup' => 'N\'oubliez pas de faire auparavant une sauvegarde compl&egrave;te de votre site. Vous devrez aussi v&eacute;rifier que vos squelettes et fichiers de langue sont compatibles @charset@.', # NEW
'utf8_convert_erreur_deja' => 'Votre site est d&eacute;j&agrave; en @charset@, inutile de le convertir...', # NEW
'utf8_convert_erreur_orig' => 'Erreur&nbsp;: le jeu de caract&egrave;res @charset@ n\'est pas support&eacute;.', # NEW
'utf8_convert_termine' => 'C\'est termin&eacute;&nbsp;!', # NEW
'utf8_convert_timeout' => '<b>Important&nbsp;:</b> en cas de <i>timeout</i> du serveur, veuillez recharger la page jusqu\'&agrave; ce qu\'elle indique &laquo;&nbsp;termin&eacute;&nbsp;&raquo;.', # NEW
'utf8_convert_verifier' => 'Vous devez maintenant aller vider le cache, et v&eacute;rifier que tout se passe bien sur les pages publiques du site. En cas de gros probl&egrave;me, une sauvegarde de vos donn&eacute;es a &eacute;t&eacute; r&eacute;alis&eacute;e (au format SQL) dans le r&eacute;pertoire @rep@.', # NEW
'utf8_convertir_votre_site' => 'Convertir votre site en utf-8', # NEW

// V
'version' => 'Version&nbsp;:', # NEW
'version_deplace_rubrique' => 'D&#233;plac&#233; de <b>&#171;&nbsp;@from@&nbsp;&#187;</b> vers <b>&#171;&nbsp;@to@&nbsp;&#187;</b>.', # NEW
'version_initiale' => 'Inicijalna verzija'
);

?>
